<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Main Menu /////////////////////////
// Buttons:
define('MAIN_MENU_CONTENT_HEADING', "CONTENT");
define('MAIN_MENU_EDIT_PAGE_BTN', "Edit Content");
define('MAIN_MENU_CREATE_PAGE_BTN', "Create Page");
define('MAIN_MENU_MANAGE_BORDER_AREAS_BTN', "Manage terminus areas");
define('MAIN_MENU_MANAGE_IMAGES_BTN', "Manage Imagines");
define('MAIN_MENU_PREVIEW_SITE_BTN', "Published Preview Site");
define('MAIN_MENU_EDIT_BLOG_BTN', "Manage | Edit Blog");
define('MAIN_MENU_EDIT_FILE_BTN', "File Edit");
define('MAIN_MENU_MENUS_HEADING', "MENUS");
define('MAIN_MENU_EDIT_MENUS_BTN', "Edit Menus");
define('MAIN_MENU_MANAGE_MENUS_BTN', "Assignments Manage Menu");
define('MAIN_MENU_EDIT_CSS_MENU_PARAMS_BTN', "Morbi Menu About Edit:");
define('MAIN_MENU_EDIT_CSS_MENU_STYLES_BTN', "Edit, Menu About Styles");
define('MAIN_MENU_EDIT_JS_MENU_PARAMS_BTN', "Edit JS-Morbi Menu");
define('MAIN_MENU_EDIT_JS_MENU_PARAMS_BTN_ALT', "Edit JavaScript-Morbi Menu");
define('MAIN_MENU_EDIT_JS_MENU_STYLES_BTN', "Edit, JS Styles Menu");
define('MAIN_MENU_EDIT_JS_MENU_STYLES_BTN_ALT', "Edit, JavaScript Styles Menu");
define('MAIN_MENU_STYLES_HEAD_CONTENT_HEADING', "Styles &amp; caput CONTENT");
define('MAIN_MENU_STYLES_HEAD_CONTENT_HEADING_ALT', "Styles et caput CONTENT");
define('MAIN_MENU_EDIT_STYLES_BTN', "Edit Styles");
define('MAIN_MENU_EDIT_HEAD_BTN', "Edit caput Code");
define('MAIN_MENU_MANAGE_HEAD_BTN', "Caput Manage Codex");
define('MAIN_MENU_EDIT_FAVICON_BTN', "Edit Favicon");
define('MAIN_MENU_PAGE_MANAGEMENT_HEADING', "Management Page");
define('MAIN_MENU_EDIT_PAGE_TITLES_BTN', "Edit Page Titles");
define('MAIN_MENU_EDIT_META_TAGS_BTN', "Tags edit Meta");
define('MAIN_MENU_DELETE_PAGE_BTN', "Delete Page vel Blog");
define('MAIN_MENU_COPY_RENAME_BTN', "Copy vel Rename Pages");
define('MAIN_MENU_RESTORE_BTN', "Redde Page");
define('MAIN_MENU_ADD_PLUGIN_TO_PAGE_BTN', "Install Plugin in Page");
define('MAIN_MENU_MANAGE_PAGE_ACCESS_BTN', "Page Manage Access");
define('MAIN_MENU_MANAGE_PAGE_ATTRIBUTES', "Page Manage attributa");
define('MAIN_MENU_SITE_MANAGEMENT_HEADING', "Site Management");
define('MAIN_MENU_RERUN_WIZARD_BTN', "Re-currit Veneficus");
define('MAIN_MENU_UPLOAD_TEMPLATE_BTN', "Upload Template");
define('MAIN_MENU_MANAGE_USERS_SITE_OPTIONS_BTN', "Users Manage &amp; Site Options");
define('MAIN_MENU_MANAGE_USERS_SITE_OPTIONS_BTN_ALT', "Users Site Manage et Options");
define('MAIN_MENU_NEW_SESSION_BTN', "Sessio NEW");
define('MAIN_MENU_LOGOUT_BTN', "LOGOUT");
// Console Text:
define('MAIN_MENU_HEADER_DIVIDER', "ANIMA dolor aedium MODULE");
// JavaScript Constants
define('MAIN_MENU_TIMEOUT_ERR', "Sessione vestra fecit opportuno. Vis in stipes?");

///////////////////////// Login /////////////////////////
// Buttons:
define('LOGIN_LOGIN_BTN', "Login");
// Console Text:
define('LOGIN_USERID_PASS_MSG', "Id intra Magno Cancellario quaeso User");
define('LOGIN_SAVE_LOGIN_MSG', "Log in Save");
define('LOGIN_FORGOT_PASSWORD_MSG', "Forgot Password?");
define('LOGIN_JS_WARNING_MSG', "CAVE: uti JavaScript sit amet lectus. Quaeso te verto JavaScipt pasco.");
define('LOGIN_ENTER_EMAIL_MSG', "Please enter vestri email ut reset vestri password");
define('LOGIN_CAPTCHA_MSG', "Typus nomen tibi ingenia aut <br /> in pictura supra <span class='small_message'>(cave litteras maiusculas minusculasque) seligendo</span>");
// Popup Messages:
define('LOGIN_CAPTCHA_ERR', "CAPTCHA tua introitu est incorrect. Quaero, iterum conare.");
define('LOGIN_BAD_EMAIL_ERR', "Ingressus est inscriptio non valet. Rursus in Isulat inscriptio.");
define('LOGIN_BAD_REFERER_ERR', "Sed non videtur esse verum.");
define('LOGIN_BAD_USER_ERR', "Inventus est nemo User email. Placere reintrare vestri email oratio.");
define('LOGIN_PASSWORD_RESET_ERR', "Novus Email vestri password missum. Profecto enim veniet sermo Placere reprehendo vestri email. Si non verbis, tuam reprehendo spambox.");
define('LOGIN_DEFAULT_ERR', "A mirum est error occurrit. Placere reprehendo flammae solaris.");
define('LOGIN_SSL_WARNING_1', "Nota: pro salute enim vestra pasco tesserae unencrypted tempore mittere indigebit. Ad hoc, tentant usura a nexu SSL encrypted (");
define('LOGIN_SSL_WARNING_2', "). Dico vestri pasco sit amet Store / post update vestri password in colligationem.");
define('LOGIN_EXCEEDED_MAX_ATTEMPTS', "Login vicisti maximum numerum conatusque prohibebit. Administrator contact vestri ratio.");
define('LOGIN_NO_USER_FOUND_ERR', "Est nomen usoris. Id quaeso password iterum introire tuis.");
define('LOGIN_NO_USER_FOUND_1_ERR', "Est nomen usoris.");
define('LOGIN_NO_USER_FOUND_2_ERR', "Id reintrare et clavem ad tuas.");
define('LOGIN_PASSWORD_NOT_CONFIRMED_MSG', "Vestri password non confirmata. Placere reintrare tua.");
define('LOGIN_PASSWORD_NOT_CONFIRMED_1_MSG', "Vestri password non confirmata.");
define('LOGIN_PASSWORD_NOT_CONFIRMED_2_MSG', "ad reintrare tua.");

///////////////////////// Version /////////////////////////
// Console Text:
define('VERSION_DB_PROGRAM_FILE_MISMATCH_MSG', "Vestri database recognitione exortus, lacus non aequas gradu progressio, lima, emendationem elit. Administrator contact vestri ratio.");
define('VERSION_PROGRAM_FILES_VERSION_MSG', "Revision Level Program Files");
define('VERSION_DB_VERSION_MSG', "Level Patch Database");

///////////////////////// Dashboard /////////////////////////
// Console Text:
define('WELCOME_1_MSG', "About");
define('WELCOME_2_MSG', "Website conditor ™ ad auras. Click quemquam sinistris capita obvius menu ratio instrumenta edificium vestri website.");
define('WELCOME_INSTALL_FOLDER_PRESENT_1_WARNING', "Installation est adhuc in in folder <b>WARNING !!!</b> tua server. Vestri site facile decipi. Please click");
define('WELCOME_INSTALL_FOLDER_PRESENT_2_WARNING', "hic");
define('WELCOME_INSTALL_FOLDER_PRESENT_3_WARNING', "delere et <b><em>install</em></b> a <b><em>SQL</em></b> Servo folder.");
define('WELCOME_LATEST_VERSION_INSTALLED_MSG', "Tardus poema aurae conditor ™ installed Website");
define('WELCOME_BETA_VERSION_INSTALLED_1_MSG', "You are currently currit Beta version");
define('WELCOME_BETA_VERSION_INSTALLED_2_MSG', "Website conditor ™ aurae. In current est stabilis solvo");
define('WELCOME_OLD_VERSION_INSTALLED_1_MSG', "Version");
define('WELCOME_OLD_VERSION_INSTALLED_2_MSG', "Website conditor ™ installed aurae. Tardus poema poematis est");
define('WELCOME_OLD_VERSION_INSTALLED_3_MSG', "Click");
define('WELCOME_OLD_VERSION_INSTALLED_5_MSG', "omnes recentiori Download <br /> files upgrade vestri current version. Nota Vos mos postulo ut install updates continue singulis horum donec installation sursum-ut-balanus.");
define('WELCOME_OLD_VERSION_INSTALLED_5A_MSG', "download tardus poema file ad upgrade.");
define('WELCOME_OLD_VERSION_INSTALLED_6_MSG', "Secundum downloading quod updates, click");
define('WELCOME_OLD_VERSION_INSTALLED_6A_MSG', "Secundum downloading update, click");
define('WELCOME_OLD_VERSION_INSTALLED_7_MSG', "hic");
define('WELCOME_OLD_VERSION_INSTALLED_8_MSG', "to install altera update.");
define('WELCOME_OLD_VERSION_INSTALLED_8A_MSG', "to install is.");
define('WELCOME_OLD_VERSION_INSTALLED_9_MSG', "Vos mos postulo ut install administratorem ut update initium. Contact ut update vestri ratio administrator ratio.");
define('WELCOME_UNKNOWN_VERSION_INSTALLED_1_MSG', "Version");
define('WELCOME_UNKNOWN_VERSION_INSTALLED_2_MSG', "Website conditor ™ installed aurae. <span class='extra_small_message'><br /> Nota quia non possumus conferentur Vulgata versio in PHP <b><i>allow_url_fopen</i></b> directiva est verto off. Ad hoc reprehendo vestri Dashboard Version et vos cum links ut suggero updates, vos mos postulo ut posuit ad <b><i>I</i></b> in <b><i>php.ini</i></b> file <b><i>allow_url_fopen.</i></b></span>");
define('WELCOME_PAGE_COUNT', "Page count:");
define('WELCOME_BLOG_COUNT', "About count:");
define('WELCOME_PLEASE_WAIT_DOWNLOADING_UPDATES_MSG', "Please wait. Download Quod plures updates ... elit.");

///////////////////////// Edit Page Select /////////////////////////
// Buttons:
define('EDIT_PAGE_SELECT_HEADING', "Edit Content");
// Console Text:
define('EDIT_PAGE_SELECT_OPTIONS_HEADING', "Editor Options");
define('EDIT_PAGE_SELECT_SOURCE_VIEW_OPTION', "Patefacio Source in");
define('EDIT_PAGE_SELECT_MOBILE_STYLE_OPTION', "Uti mobile Styles");
define('EDIT_PAGE_SELECT_SITE_STYLES_HEADING', "Site Styles");
define('EDIT_PAGE_SELECT_PAGE_DEFAULT_STYLES_OPTION', "Default Use");
define('EDIT_PAGE_SELECT_SITE_DEFAULT_STYLES_OPTION', "Site Styles");
define('EDIT_PAGE_SELECT_DISABLE_SITE_STYLES_OPTION', "Disable Styles Site");

/////////////// HTML/JavaScript/PHP/CSS Editor Pages /////////////////
// Buttons:
define('EDITOR_PREVIEW', "Preview");
define('EDITOR_SAVE', "nisi");
define('EDITOR_SAVE_AS', "Save As");
define('EDITOR_PUBLISH', "publish");
define('EDITOR_REVERT', "revertere");
define('EDITOR_DELETE', "Delete");
define('EDITOR_SEE_SITE', "See site");
define('EDITOR_SEE_FILE', "See Fasciculus");
define('EDITOR_CLEAR', "Aequaliter Nubila");
define('EDITOR_OPTIMIZE_IMAGES', "optimize Images");
define('EDITOR_RESET_IMAGES', "Reset Images");
define('EDITOR_EDIT_STYLES', "Edit Styles");
// Console Text:
define('EDITOR_PAGE_NAME', "Page Name");
define('EDITOR_FILE_NAME', "File nomen");
define('EDITOR_HEAD_NAME', "caput Name");
define('EDITOR_STYLE_SHEET', "style");
// Popup Messages:
define('EDITOR_STARTING_UPDATE_MSG', "Satus Update ...");
define('EDITOR_PREPARING_PREVIEW_MSG', "Praeparans Preview ...");
define('EDITOR_REVERT_BLOG_CONFIRM_1_MSG', "Visne tu te reverti <b>id Blog</b>");
define('EDITOR_REVERT_BLOG_CONFIRM_2_MSG', "?");
define('EDITOR_REVERT_AREA_CONFIRM_1_MSG', "Es vos certus vos volo ut revertantur in");
define('EDITOR_REVERT_AREA_CONFIRM_2_MSG', "area?");
define('EDITOR_REVERT_PAGE_CONFIRM_1_MSG', "Es vos certus vos volo ut revertantur in");
define('EDITOR_REVERT_PAGE_CONFIRM_2_MSG', "page?");
define('EDITOR_REVERT_FILE_CONFIRM_1_MSG', "Es vos certus vos volo ut revertantur in");
define('EDITOR_REVERT_FILE_CONFIRM_2_MSG', "lima?");
define('EDITOR_REVERT_HEAD_CONFIRM_1_MSG', "Es vos certus vos volo ut revertantur in");
define('EDITOR_REVERT_HEAD_CONFIRM_2_MSG', "caput?");
define('EDITOR_REVERT_CSS_CONFIRM_1_MSG', "Es vos certus vos volo ut revertantur in");
define('EDITOR_REVERT_CSS_CONFIRM_2_MSG', "CSS?");
define('EDITOR_REVERTING_MSG', "Redeunt rursus ad ultimum edidit Vulgata ...");
define('EDITOR_REVERT_COMPLETE_MSG', "revertere perfecta");
define('EDITOR_PAGE_NOT_SAVED_MSG', "Page tuus est: non salvus. Vis servare mutationes?");
define('EDITOR_FILE_NOT_SAVED_MSG', "Your file non salvabitur. Vis servare mutationes?");
define('EDITOR_HEAD_NOT_SAVED_MSG', "Caput tuum non est salus. Vis servare mutationes?");
define('EDITOR_CSS_NOT_SAVED_MSG', "About tua non salvabitur. Vis servare mutationes?");
define('EDITOR_PAGE_BLANK_ERR', "Page name non vestis. Please enter rursum pagina nomen.");
define('EDITOR_FILE_BLANK_ERR', "File name non vestis. Please enter rursum lima nomen.");
define('EDITOR_FOLDER_BLANK_ERR', "Pellentesque sit nomen vestis possunt. Placere folder nomine rursum intrare.");
define('EDITOR_HEAD_BLANK_ERR', "Nomen vestis possunt esse caput. Please enter rursum capite et nomine.");
define('EDITOR_PAGE_ALREADY_EXISTS_1_ERR', "Page");
define('EDITOR_PAGE_ALREADY_EXISTS_2_ERR', "iam est. Index renominationum imitere ingredere ad pages Char.");
define('EDITOR_AREA_ALREADY_EXISTS_1_ERR', "terminus area");
define('EDITOR_AREA_ALREADY_EXISTS_2_ERR', "iam est. Ingredere ad terminos moderari Char elit.");
define('EDITOR_FILE_ALREADY_EXISTS_1_ERR', "file:");
define('EDITOR_FILE_ALREADY_EXISTS_2_ERR', "iam est. Index renominationum ingredere ad vestri lima imitere Char.");
define('EDITOR_FOLDER_ALREADY_EXISTS_1_ERR', "folder");
define('EDITOR_FOLDER_ALREADY_EXISTS_2_ERR', "iam est.");
define('EDITOR_ERROR_CREATING_FOLDER_ERR', "Error non poterat facere folder.");
define('EDITOR_HEAD_ALREADY_EXISTS_1_ERR', "caput");
define('EDITOR_HEAD_ALREADY_EXISTS_2_ERR', "iam est. Index renominationum et ingredere ad capita elata Char.");
define('EDITOR_DELETE_BLOG_CONFIRM_1_MSG', "Es vos certus vos volo ut delete <b>id Blog</b>");
define('EDITOR_DELETE_BLOG_CONFIRM_2_MSG', "?");
define('EDITOR_DELETE_AREA_CONFIRM_1_MSG', "Es vos certus vos volo ut delete");
define('EDITOR_DELETE_AREA_CONFIRM_2_MSG', "area?");
define('EDITOR_DELETE_PAGE_CONFIRM_1_MSG', "Es vos certus vos volo ut delete");
define('EDITOR_DELETE_PAGE_CONFIRM_2_MSG', "page?");
define('EDITOR_DELETE_FILE_CONFIRM_1_MSG', "Es vos certus vos volo ut delete");
define('EDITOR_DELETE_FILE_CONFIRM_2_MSG', "lima?");
define('EDITOR_DELETE_HEAD_CONFIRM_1_MSG', "Es vos certus vos volo ut delete");
define('EDITOR_DELETE_HEAD_CONFIRM_2_MSG', "caput?");


///////////////////////// Create Page Select /////////////////////////
// Buttons:
define('CREATE_PAGE_SELECT_HEADING', "Create Page");
define('CREATE_PAGE_SELECT_ENTER_PAGE_NAME_BTN', "Enter of Page");
define('CREATE_PAGE_SELECT_ADD_PLUGIN_BTN', "Add Plugin");
define('CREATE_PAGE_SELECT_SELECT_LAYOUT_BTN', "Select Layout");
// Popup Messages:
define('CREATE_PAGE_SELECT_CREATING_A_PAGE', "Partum a Page");
define('CREATE_PAGE_SELECT_SELECTING_PAGE_LAYOUT', "Delectos Page Layout");
define('CREATE_PAGE_SELECT_HELPFUL_TIPS', "benevolens tips");

///////////////////////// Create Page Select /////////////////////////
// Console Text:
define('CREATE_PAGE_PAGE_NAME_BLANK_1_ERR', "X! Confiteantur tibi luscum pagina nomen.");
define('CREATE_PAGE_PAGE_NAME_BLANK_2_ERR', "et ingressus est pagina nomen.");
define('CREATE_PAGE_PAGE_ALREADY_EXISTS_ERR', "Page name intrare alium.");
define('CREATE_PAGE_DEFAULT_CONTENT', "Nulla contentus est.");

///////////////////////// Manage Border Area Select /////////////////////////
// Buttons:
define('EDIT_BORDER_AREA_SELECT_HEADING', "Edit terminus areas");
define('MANAGE_BORDER_AREA_HEADING', "Manage terminus areas");
define('MANAGE_BORDER_AREA_BTN', "Custom Manage terminus areas");

///////////////////////// Manage Border Areas /////////////////////////
// Buttons:
define('MANAGE_CUSTOM_BORDER_AREA_HEADING', "Custom Manage terminus areas");
// Console Text:
define('MANAGE_CUSTOM_BORDER_AREA_ADD_AREA', "Add terminus area");
define('MANAGE_CUSTOM_BORDER_AREA_ASSIGN_AREA', "Tribue terminus area Page");
define('MANAGE_CUSTOM_BORDER_AREA_RENAME_AREA', "Terminus area Rename");
define('MANAGE_CUSTOM_BORDER_AREA_DELETE_AREA', "Delete terminus area");
define('MANAGE_CUSTOM_BORDER_AREA_RENAME_AREA_SELECT', "Select terminus area ut rename");
define('MANAGE_CUSTOM_BORDER_AREA_NEW_NAME', "nomine");
define('MANAGE_CUSTOM_BORDER_AREA_DELETE_AREA_SELECT', "Select terminus area ut delete");
// Popup Messages:
define('MANAGE_CUSTOM_BORDER_AREA_DELETE_AREA_CONFIRM_1_MSG', "Es vos certus vos volo ut delete");
define('MANAGE_CUSTOM_BORDER_AREA_DELETE_AREA_CONFIRM_2_MSG', "area?");
define('MANAGE_CUSTOM_BORDER_AREA_DELETED_1_MSG', "Terminus area");
define('MANAGE_CUSTOM_BORDER_AREA_DELETED_2_MSG', "deletum.");
define('MANAGE_CUSTOM_BORDER_AREA_DELETED_ERR', "Error non poterat addere terminus area");
define('MANAGE_CUSTOM_BORDER_AREA_NOT_FOUND_1_ERR', "non est.");
define('MANAGE_CUSTOM_BORDER_AREA_NOT_FOUND_2_ERR', "return to page ad munus area.");
define('MANAGE_CUSTOM_BORDER_AREA_ASSIGNED_1_MSG', "Assignari terminus areas sunt re-");
define('MANAGE_CUSTOM_BORDER_AREA_ASSIGNED_2_MSG', "page.");
define('MANAGE_CUSTOM_BORDER_AREA_ASSIGNED_1_ERR', "Error: terminus assignari non posset in locis");
define('MANAGE_CUSTOM_BORDER_AREA_ASSIGNED_2_ERR', "page.");
define('MANAGE_CUSTOM_BORDER_AREA_NO_AREAS_FOUND_ERR', "ERROR: no invenitur terminus areas.");
define('MANAGE_CUSTOM_BORDER_AREA_ADDED_1_MSG', "Terminus area");
define('MANAGE_CUSTOM_BORDER_AREA_ADDED_2_MSG', "additum.");
define('MANAGE_CUSTOM_BORDER_AREA_ADDED_ERR', "Error non poterat addere terminus area");
define('MANAGE_CUSTOM_BORDER_AREA_RENAMED_MSG', "has been added ut");
define('MANAGE_CUSTOM_BORDER_AREA_RENAMED_ERR', "Error: could not rename");
define('MANAGE_CUSTOM_BORDER_AREA_ALREADY_ASSIGNED_1_ERR', "Terminus assignari non posset in locis");
define('MANAGE_CUSTOM_BORDER_AREA_ALREADY_ASSIGNED_3_ERR', "page quia iam assignata.");

///////////////////////// Edit Blog Select /////////////////////////
// Buttons:
define('EDIT_BLOG_SELECT_CREATE_HEADING', "Create blog on Page");
define('EDIT_BLOG_SELECT_EDIT_HEADING', "Post Edit");

///////////////////////// Edit File Select /////////////////////////
// Buttons:
define('EDIT_FILE_SELECT_HEADING', "File Edit");
define('EDIT_FILE_SELECT_PAGE_FILES_BTN', "Edit Page Files");
define('EDIT_FILE_SELECT_INCLUDE_SCRIPTS_BTN', "Comprehendo Scriptor Edit");
define('EDIT_FILE_SELECT_LIB_MODULES_BTN', "Edit Library of Modules");
// Console Text:
define('EDIT_FILE_SELECT_SELECT_FILE', "File Select");
// Popup Messages:
define('EDIT_FILE_SELECT_NO_FOLDER_ERR', "ERROR: no determinatur folder");

///////////////////////// Edit Menu Items /////////////////////////
// Buttons:
define('EDIT_MENU_ITEMS_HEADING', "Edit Menus");
define('EDIT_MENU_ITEMS_UPDATE_ALL_BTN', "Omnia Update");
// Console Text:
define('EDIT_MENU_ITEMS_SELECT_MENU', "Select addere items in menu");
define('EDIT_MENU_ITEMS_ITEM_TEXT', "Item Text");
define('EDIT_MENU_ITEMS_NESTING_LEVEL', "Level nesting");
define('EDIT_MENU_ITEMS_URL', "URL");
define('EDIT_MENU_ITEMS_TARGET_WINDOW', "Target Fenestra");
define('EDIT_MENU_ITEMS_TOP_LEVEL', "Top Level");
define('EDIT_MENU_ITEMS_1ST_SUB_LEVEL', "1 Sub Level");
define('EDIT_MENU_ITEMS_2ND_SUB_LEVEL', "2 Sub Level");
define('EDIT_MENU_ITEMS_3RD_SUB_LEVEL', "Sub Level 3");
define('EDIT_MENU_ITEMS_4TH_SUB_LEVEL', "4 Sub Level");
define('EDIT_MENU_ITEMS_5TH_SUB_LEVEL', "5 Sub Level");
define('EDIT_MENU_ITEMS_SELECT_MENU_MSG', "Select a menu menu edit.");
// Popup Messages:
define('EDIT_MENU_ITEMS_DELETE_ITEM_CONFIRM_1_MSG', "Es vos certus vos volo ut delete");
define('EDIT_MENU_ITEMS_DELETE_ITEM_CONFIRM_2_MSG', "item?");
define('EDIT_MENU_ITEMS_STARTING_DELETE_MSG', "Satus delete ...");
define('EDIT_MENU_ITEMS_LOCATING_MENU_ITEMS_MSG', "Locating menu items ...");
define('EDIT_MENU_ITEMS_COULD_NOT_DELETE_ITEM_MSG', "No records. Item deleri non potuit.");
define('EDIT_MENU_ITEMS_MENU_ITEM_DELETED_MSG', "Menu item delevit");
define('EDIT_MENU_ITEMS_DELETING_MENU_ITEM_MSG', "Deleting item ...");
define('EDIT_MENU_ITEMS_COULD_NOT_UPDATE_ITEM_MSG', "Testimonium non invenitur. An update, non item.");
define('EDIT_MENU_ITEMS_MENU_ITEM_UPDATED_MSG', "Menu item updated");
define('EDIT_MENU_ITEMS_UPDATING_MENU_ITEM_MSG', "Adaequationis item ...");
define('EDIT_MENU_ITEMS_COULD_NOT_UPDATE_ITEMS_MSG', "Testimonium non invenitur. Numquid non update menu items.");
define('EDIT_MENU_ITEMS_MENU_ITEMS_UPDATED_MSG', "Updated menu items");
define('EDIT_MENU_ITEMS_UPDATING_MENU_ITEMS_MSG', "Iwiki + menu items ...");
define('EDIT_MENU_ITEMS_RETRIEVING_MENU_ITEMS_MSG', "Retrieving menu items ...");
define('EDIT_MENU_ITEMS_NOT_SAVED_CONFIRM_MSG', "Commutationes tuae non servatae sunt. Vis ad servare mutationes Char rediturus?");

///////////////////////// Manage Menu Assignments /////////////////////////
// Buttons:
define('MANAGE_MENUS_HEADING', "Assignments Manage Menu");
define('MANAGE_MENUS_CREATE_NEW_MENU_BTN', "Create New Menu");
// Console Text:
define('MANAGE_MENUS_ADD_MENU', "Add Menu");
define('MANAGE_MENUS_MENU_TYPE', "Type Menu");
define('MANAGE_MENUS_ASSIGN_MENU_TO_BORDER', "Tribue est terminus area Menu");
define('MANAGE_MENUS_DELETE_MENU', "Delete Menu");
define('MANAGE_MENUS_SELECT_MENU_TO_DELETE', "Lego delere vis menu");
define('MANAGE_MENUS_UPDATE_MENU_DESCRIPTION', "Update Menu Description");
define('MANAGE_MENUS_SELECT_MENU_TO_REVISE', "Lego retractari vis menu");
define('MANAGE_MENUS_NEW_DESCRIPTION', "Description New");
// Popup Messages:
define('MANAGE_MENUS_REASSIGN_MENU_TO_COMPLETE_MSG', "Vos mos postulo iterum ad terminum regionem assignare menu perficere conversionem.");
define('MANAGE_MENUS_DELETE_MENU_CONFIRM_1_MSG', "Es vos certus vos volo ut delete");
define('MANAGE_MENUS_DELETE_MENU_CONFIRM_2_MSG', "menu?");
define('MANAGE_MENUS_MENU_ASSIGNED_1_MSG', "quod");
define('MANAGE_MENUS_MENU_ASSIGNED_2_MSG', "Menu");
define('MANAGE_MENUS_MENU_ASSIGNED_3_MSG', "has datum est");
define('MANAGE_MENUS_MENU_ASSIGNED_4_MSG', "terminus area.");

///////////////////////// Edit CSS Menu Parameters /////////////////////////
// Buttons:
define('EDIT_CSS_MENU_PARAMETERS_HEADING', "Velox-setup Author Menu About Parameters");
// Console Text:
define('EDIT_CSS_MENU_PARAMETERS_SELECT_MENU', "Select a menu setup");
define('EDIT_CSS_MENU_PARAMETERS_LAYOUT_ORIGIN', "Menu layout et origo (e superiore sinistro page)");
define('EDIT_CSS_MENU_PARAMETERS_LOCATION', "Location Menu");
define('EDIT_CSS_MENU_PARAMETERS_FIXED_WIDTH', "(Fixed width)");
define('EDIT_CSS_MENU_PARAMETERS_VARIABLE_WIDTH', "(Variabilis latitudine)");
define('EDIT_CSS_MENU_PARAMETERS_MENU_WIDTH', "Menu Width");
define('EDIT_CSS_MENU_PARAMETERS_SPECIAL_NOTE', "Nota delectos locus non est ponere aliquod unum de menu elit. Quod solum effert hac forma, in propria loca in area lego.");
define('EDIT_CSS_MENU_PARAMETERS_ITEM_SIZE_PADDING', "Pellentesque et libero Size");
define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_POSITIONING', "Sub Positioning Menu");
define('EDIT_CSS_MENU_PARAMETERS_OFFSET_FROM_TOP', "Cinguli de Top");
define('EDIT_CSS_MENU_PARAMETERS_OFFSET_FROM_LEFT', "Cinguli a sinistro");
define('EDIT_CSS_MENU_PARAMETERS_COLLAPSE_EXPAND', "Et Expand Collapse");
define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_SIZE_PADDING', "Sub Size Pellentesque et libero");
define('EDIT_CSS_MENU_PARAMETERS_SELECT_MENU_MSG', "Select a menu habeat.");

///////////////////////// Edit CSS Menu Styles /////////////////////////
// Buttons:
define('EDIT_CSS_MENU_STYLES_HEADING', "Velox-setup Author Menu About Styles");
// Console Text:
define('EDIT_CSS_MENU_STYLES_SELECT_MENU', "Select a menu ut dicam");
define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_FONT', "Top Level Font");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_FONT', "Sub Level I Font");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_FONT', "Sub Level II Font");
define('EDIT_CSS_MENU_STYLES_COLORS_BACKGROUND', "Colores, et Background");
define('EDIT_CSS_MENU_STYLES_NORMAL_MOUSE_OUT', "Normal (de mus)");
define('EDIT_CSS_MENU_STYLES_HOVER_MOUSE_OVER', "Hover (in Mus)");
define('EDIT_CSS_MENU_STYLES_ACTIVE_MOUSE_CLICK', "Active (click mus)");
define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_TEXT_COLOR', "Color summo gradu Text");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_TEXT_COLOR', "Level I Text Sub Color");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_TEXT_COLOR', "Level II Text Sub Color");
define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BACKGROUND_COLOR', "Top Level Background Colo");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BACKGROUND_COLOR', "Sub Level Background Colo");
define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BLOCK_BORDER_COLOR', "Top Level Block Border Color");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_BLOCK_BORDER_COLOR', "Acta Border Color sub Level I");
define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_ITEM_BORDER_COLOR', "Top Item Level Border Color");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_ITEM_BORDER_COLOR', "Item Level Color sub limite");
define('EDIT_CSS_MENU_STYLES_TOP_BORDER_VERTICAL', "T <br> O <br> p");
define('EDIT_CSS_MENU_STYLES_BOTTOM_BORDER_VERTICAL', "B <br> O <br> T <br> T <br> O <br> m");
define('EDIT_CSS_MENU_STYLES_LEFT_BORDER_VERTICAL', "L <br> E <br> F <br> T");
define('EDIT_CSS_MENU_STYLES_RIGHT_BORDER_VERTICAL', "R <br> ego <br> G <br> H <br> T");
define('EDIT_CSS_MENU_STYLES_UNDERLINE_NOTE', "In off-Link underline cogetur, nisi underline cohibetur");
define('EDIT_CSS_MENU_STYLES_SAME_AS_TOP_LEVEL_NOTE', "(Quod summo gradu)");
define('EDIT_CSS_MENU_STYLES_SAME_AS_NORMAL_NOTE', "(Ut idem normalis)");
define('EDIT_CSS_MENU_STYLES_SELECT_MENU_MSG', "Select a menu turpis.");
// Popup Messages:
define('EDIT_CSS_MENU_STYLES_LETTER_SPACING_MSG', "<b>Normal</b> delecti estis <b>initialis</b> <b>ullum</b> tuas litteras eros nec eros litteras tamen plures posuit. Et nota quod elegimus numerus ignoretur. Si vis epistulam ad color, potius elegit <b>px.</b>");
define('EDIT_CSS_MENU_STYLES_SAVE_SUCCESS_MSG', "Modis ereptum vestra menu.");
define('EDIT_CSS_MENU_STYLES_SAVE_FAIL_ERR', "Menu styles salva fuit error.");

///////////////////////// Edit JS Menu Parameters /////////////////////////
// Buttons:
define('EDIT_JS_MENU_PARAMETERS_HEADING', "JavaScript Size et intentio Author Menu");
// Console Text:
define('EDIT_JS_MENU_PARAMETERS_SELECT_MENU', "Select a menu setup");
define('EDIT_JS_MENU_PARAMETERS_MENU_ITEM_SIZE', "Menu Item Size");
define('EDIT_JS_MENU_PARAMETERS_MENU_ORIGIN', "Menu Origine (e superiore sinistro page)");
define('EDIT_JS_MENU_PARAMETERS_SUB_MENU_ORIGIN', "Sub Menu Origine (Char e superiore sinistro)");
define('EDIT_JS_MENU_PARAMETERS_MENU_ITEM_OFFSET', "Menu Item cinguli");
define('EDIT_JS_MENU_PARAMETERS_SUB_MENU_ITEM_OFFSET_SIZE', "Sub Menu Item Size et cinguli");
define('EDIT_JS_MENU_PARAMETERS_PROPORTIONAL_SIZING', "proportionalis Sizing");
define('EDIT_JS_MENU_PARAMETERS_SUB_MENU_WIDTH', "Sub Menu Item Width");
define('EDIT_JS_MENU_PARAMETERS_SUB_MENU_HEIGHT', "Sub Menu Item Height");
define('EDIT_JS_MENU_PARAMETERS_OFFSET_FROM_LEFT_OF_TOP_MENU', "Cinguli a sinistro capitis Menu");
define('EDIT_JS_MENU_PARAMETERS_HIDE_DELAY_ON_MOUSE_OUT', "Ex pelle moram postquam Mus (msec)");
define('EDIT_JS_MENU_PARAMETERS_VERTICAL_HORIZONTAL_MENU_NOTE', "Nota: pro verticalis a reliquit ad cinguli set menu menu set cinguli a summo usque ad horizontem in 0. 0.");
define('EDIT_JS_MENU_PARAMETERS_SELECT_MENU_MSG', "Select a menu habeat.");
// Popup Messages:
define('EDIT_JS_MENU_PARAMETERS_SAVE_SUCCESS_MSG', "Parametri vestra menu salvari potuisset.");
define('EDIT_JS_MENU_PARAMETERS_SAVE_FAIL_ERR', "Menu parametri salva facta est error.");

///////////////////////// Edit JS Menu Styles /////////////////////////
// Buttons:
define('EDIT_JS_MENU_STYLES_HEADING', "JavaScript Styles Author Menu");
// Console Text:
define('EDIT_JS_MENU_STYLES_SELECT_MENU', "Select a menu ut dicam");
define('EDIT_JS_MENU_STYLES_TOP_MENU_MENU', "Summo LIBELLA Menu");
define('EDIT_JS_MENU_STYLES_SUB_LEVEL_1_MENU', "Sub-gradu I Menu");
define('EDIT_JS_MENU_STYLES_SUB_LEVEL_2_MENU', "II sub-gradu Menu");
define('EDIT_JS_MENU_STYLES_PADDING', "Nam libero tempore (summo iure imo sinistram)");
define('EDIT_JS_MENU_STYLES_SELECT_MENU_MSG', "Select a menu turpis.");

///////////////////////// Edit CSS Select /////////////////////////
// Buttons:
define('EDIT_CSS_SELECT_HEADING', "Edit Styles");
define('EDIT_CSS_SELECT_COPY_STYLES_TO_MOBILE_BTN', "Inter exemplum Penicullus Ovis Desktop / Mobile / Touchscreen");
define('COPY_STYLE_TO_MOBILE_NOTE', "Desktop pro munere initializing mobile vel ad similitudinem stili Tag desktop diversa genera mobile aliquando Tag erigerent expleto rudentis aliqua styli desktop mobilis Tag felis. Hoc munus in usus overwrite quis creavit te ad locum desideratum desktop, sive mobile nervis imitati sunt touchscreen style es. Hoc munus non est necessarium, sed potest esse habilis non est ita, post initium dicendi generibus a mobili pro partum vestri desktop website, vel e converso. Item, vos potest creare seu mobilis touchscreen style rudentis style-type: non similiter mobile per default Style rudentis.");
define('COPY_STYLE_TO_MOBILE_CONFIRM_1_MSG', "Tu cave ne imitari velis");
define('COPY_STYLE_TO_MOBILE_CONFIRM_2_MSG', "? Omnes styles in");
define('COPY_STYLE_TO_MOBILE_CONFIRM_3_MSG', "overwritten erit. (Hoc non potest non esse quod factum est.)");
define('COPY_STYLE_TO_MOBILE_COMPLETE_MSG', "ut has been transtulerunt");
define('COPY_STYLE_TO_MOBILE_COMPLETE_ERR', "Fuit error effingo");
// Popup Messages:
define('EDIT_CSS_SELECT_MENU_WARNING', "CAVE: vagus Editing CSS potest immediate consequitur. In menu menu text fieri per style editors. Emendo CSS CSS Editor in acie per tela tantum tincidunt.");
define('EDIT_CSS_SELECT_MENU_ITEM_WARNING', "Vivamus: et ita, cum singulis menu items, set Display &#39;est&#39; List Item, movere in eorum web navigatores.");

///////////////////////// Edit CSS /////////////////////////
// Buttons:
define('EDIT_CSS_HEADING', "Edit Styles");
define('EDIT_CSS_ADD_DELETE_CUSTOM_STYLE_BTN', "Add / Delete Custom Style");
define('EDIT_CSS_LOAD_BROWSER_RESET_CSS_BTN', "Load Reset CSS Browser");
define('EDIT_CSS_SETUP_CENTERED_PAGES_BTN', "Pages setup pro reflecteretur");
define('EDIT_CSS_SETUP_STICKY_FOOTER_BTN', "Pellentesque setup pro Footer");
// Console Text:
define('EDIT_CSS_CHANGE_STYLE_SHEET', "Style mutatum Sheet");
define('EDIT_CSS_USE_SETTINGS_BELOW', "Use Occasus Infra");
define('EDIT_CSS_GO_TO', "Go to");
define('EDIT_CSS_SORT_ALPHABETICALLY', "Sort Reserves");
define('EDIT_CSS_CLICK_NONE_MSG', "Click &#39;non&#39; tantum, non ad exigendum explicite text color.");
define('EDIT_CSS_WHITE_SPACE', "Tractus Albus");
define('EDIT_CSS_TABLE_LAYOUT', "Table");
define('EDIT_CSS_CURSOR', "Cursor");
define('EDIT_CSS_OUTLINE_STYLE', "outline Style");
define('EDIT_CSS_BORDER_COLLAPSE', "terminus Collapse");
define('EDIT_CSS_TOP_LEFT', "top");
define('EDIT_CSS_TOP_RIGHT', "Top right");
define('EDIT_CSS_BOTTOM_RIGHT', "bottom");
define('EDIT_CSS_BOTTOM_LEFT', "imo sinistram");
define('EDIT_CSS_Z_INDEX', "Z Index");
define('EDIT_CSS_BACKGROUND_IMAGE', "background image");
define('EDIT_CSS_CLICK_AUTO_MSG', "Click &#39;Auto, tantum exigendum, ut auto margine manifeste.");
define('EDIT_CSS_REPEAT_HORIZONTALLY', "repeat Horizontally");
define('EDIT_CSS_REPEAT_VERTICALLY', "repeat Vertically");
define('EDIT_CSS_NO_REPEAT', "non Repeat");
define('EDIT_CSS_INLINE_BLOCK', "Inline-block");
define('EDIT_CSS_LIST_ITEM', "List");
define('EDIT_CSS_RUN_IN', "currite");
define('EDIT_CSS_INLINE_TABLE', "Tabula inline");
define('EDIT_CSS_TABLE_ROW_GROUP', "Tabula Row Group");
define('EDIT_CSS_TABLE_FOOTER_GROUP', "Tabula Footer Group");
define('EDIT_CSS_TABLE_ROW', "Tabula Row Group");
define('EDIT_CSS_TABLE_COLUMN_GROUP', "Tabula Group Column");
define('EDIT_CSS_TABLE_COLUMN', "Tabula Group Column");
define('EDIT_CSS_TABLE_CELL', "Tabula Cell");
define('EDIT_CSS_TABLE_CAPTION', "Tabula Caption");
define('EDIT_CSS_ALL_SCROLL', "omnes Scroll");
define('EDIT_CSS_CONTEXT_MENU', "contigi Menu");
define('EDIT_CSS_COLUMN_RESIZE', "Column Resize");
define('EDIT_CSS_ROW_RESIZE', "Row Resize");
define('EDIT_CSS_NO_DROP', "Non STALAGMIUM");
define('EDIT_CSS_NOT_ALLOWED', "non licet,");
define('EDIT_CSS_VERTICAL_TEXT', "vertical Text");
define('EDIT_CSS_EAST_RESIZE', "East-Resize");
define('EDIT_CSS_EAST_WEST_RESIZE', "East West-Resize");
define('EDIT_CSS_NORTH_RESIZE', "North Resize");
define('EDIT_CSS_NORTH_EAST_RESIZE', "South East-Resize");
define('EDIT_CSS_NORTH_EAST_SOUTH_WEST_RESIZE', "West Resize austro ad aquilonem");
define('EDIT_CSS_NORTH_SOUTH_RESIZE', "North-meridiem Resize");
define('EDIT_CSS_NORTH_WEST_RESIZE', "North-West Resize");
define('EDIT_CSS_NORTH_WEST_SOUTH_EAST_RESIZE', "North-West-South-oriente Resize");
define('EDIT_CSS_SOUTH_RESIZE', "South Resize");
define('EDIT_CSS_SOUTH_EAST_RESIZE', "South East-Resize");
define('EDIT_CSS_SOUTH_WEST_RESIZE', "North-West Resize");
define('EDIT_CSS_WEST_RESIZE', "West Resize");
define('EDIT_CSS_ZOOM_IN', "In Zoom");
define('EDIT_CSS_ZOOM_OUT', "Zoom out");
define('EDIT_CSS_TOP_CENTER', "Top Center");
define('EDIT_CSS_CENTER_LEFT', "Left Center");
define('EDIT_CSS_CENTER_CENTER', "Center");
define('EDIT_CSS_CENTER_RIGHT', "Center right");
define('EDIT_CSS_BOTTOM_CENTER', "bottom center");
define('EDIT_CSS_XPOS_YPOS', "xPos ypos");
define('EDIT_CSS_DECIMAL_LEADING_ZERO', "Decimal Nulla Leading");
define('EDIT_CSS_LOWER_ROMAN', "Romani inferioris");
define('EDIT_CSS_UPPER_ROMAN', "superior Romanus");
define('EDIT_CSS_LOWER_ALPHA', "alpha inferioris");
define('EDIT_CSS_UPPER_ALPHA', "alpha superiorem");
define('EDIT_CSS_LOWER_GREEK', "Graece inferioris");
define('EDIT_CSS_LOWER_LATIN', "Latine inferioris");
define('EDIT_CSS_UPPER_LATIN', "superiore Latinae");
define('EDIT_CSS_CJK_IDEOGRAPHIC', "CJK Ideographic,");
define('EDIT_CSS_HIRAGANA', "Hiragana");
define('EDIT_CSS_KATAKANA', "Katakana");
define('EDIT_CSS_HIRAGANA_IROHA', "Hiragana Iroha");
define('EDIT_CSS_KATAKANA_IROHA', "Katakana Iroha");
// Popup Messages:
define('EDIT_CSS_CLICK_UPDATE_TO_COMMIT_MSG', "Click &quot;Update &#39;mutationes, ut accidere.");
define('EDIT_CSS_UPDATE_COMPLETE_MSG', "The New");
define('EDIT_CSS_UPDATE_READY_TO_SEND_MSG', "Update ut mittat ...");
define('EDIT_CSS_UPDATE_SENT_MSG', "Update misit");
define('EDIT_CSS_UPDATING_MSG', "Updating ...");
define('EDIT_CSS_RESET_BROWSER_CSS_COMPLETE_MSG', "About reset vestri pasco est agitando omnia habeat margines paddings HTML elementum terminis tuis et 0, 0 omnes orae corpus elementum.");
define('EDIT_CSS_LOAD_CENTERED_PAGES_CSS_ALERT_MSG', "Nunc turpis styles quod erit occasus in vestri website faceret conlocatum centrum cum apparent ad certam latitudine.");
define('EDIT_CSS_LOAD_CENTERED_PAGES_CSS_COMPLETE_MSG', "Your site est medium. Vos may volo retractari corpus latitudine corpus color background et &#39;#wrap&#39; colorem Backgound luctus.");
define('EDIT_CSS_LOAD_STICKY_FOOTERS_ALERT_MSG', "Nunc turpis ut faciam footer fundis stili vestri web pages &#39;lignum&#39; fenestram vestri pasco angustiore ad infimum fastigio.");
define('EDIT_CSS_LOAD_STICKY_FOOTERS_COMPLETE_MSG', "Your Footer imo iam tenere pasco fenestra. Vos may quoque volo retractari &#39;Footer altitudo font color et luctus. Exsisto certus ut in summo margine footer est in eodem, sed negative footer est in altitudine.");
define('EDIT_CSS_BORDER_REQUIREMENTS_MSG', "Videtur quod habeat terminum conantur, sed non habent partem elegit. Oportet te reprehendo boxes titulus <b>capitis</b> saltem, <b>imo,</b> <b>an ad</b> <b>ius.</b>");
define('EDIT_CSS_BORDER_REQUIREMENTS_STYLE_ADENDUM_MSG', "Tibi opus est ut <b>terminus</b> terminum <b>moris</b> ostentant.");
define('EDIT_CSS_LETTER_SPACING_REQUIREMENTS_MSG', "<b>Normal</b> delecti estis <b>initialis</b> <b>ullum</b> tuas litteras eros nec eros litteras tamen plures posuit. Et nota quod elegimus numerus ignoretur. Si vis epistulam ad color, potius elegit <b>px.</b>");
define('EDIT_CSS_LINE_HEIGHT_REQUIREMENTS_MSG', "<b>Normal</b> delecti estis propter <b>ullum</b> versus sursum versus positi estis altitudinis numerus positivus. Et nota quod elegimus numerus ignoretur. Si vis ad perpendiculum altitudo, <b>Bultiplyer</b> eligere, vel <b><b>px%</b></b> instead.");
define('EDIT_CSS_SORTING_CLASS_LIST_MSG', "Genus genus List ...");
define('EDIT_CSS_SORT_COMPLETE', "The Sort");
define('EDIT_CSS_SORTING_MSG', "Genus ...");
define('EDIT_CSS_COULD_NOT_RENAME_1_ERR', "Numquid non rename");
define('EDIT_CSS_COULD_NOT_RENAME_2_ERR', "ut");
define('EDIT_CSS_CANT_CREATE_ERR', "Non potest");
define('EDIT_CSS_SELECT_PAGE_FOR_PREVIEW', "Select a page ut vestri CSS mutationes preview");

///////////////////////// Edit CLASSES /////////////////////////
// Buttons:
define('CLASSES_HEADING', "Add / Delete Custom Style");
define('CLASSES_BACK_TO_EDIT_CSS', "Back Site ut CSS Edit");
// Console Text:
define('CLASSES_ADD_CLASS', "Add Class");
define('CLASSES_CREATE_SUB_CLASS', "Create Class / relatione Genus");
define('CLASSES_DELETE_CLASS', "Class Delete");
define('CLASSES_EDIT_CLASS_DESCRIPTION', "Class Edit Description");
define('CLASSES_SET_CLASS_SORT_ORDER', "Set Class Genus Ordo");
define('CLASSES_CREATE_LINK_SET', "Create Set Link");
define('CLASSES_CLASS_DESCRIPTION', "Class / Description");
define('CLASSES_CLASS_ID_NOTE', "Select &#39;Class&#39; pro. (Dot) praepositione aut lego &#39;Id enim praeposita #.");
define('CLASSES_COPY_CLASS', "Copy / Class Rename");
define('CLASSES_FROM_CLASS', "a Class");
define('CLASSES_TO_CLASS', "Ad Class");
define('CLASSES_TO_STYLE_SHEET', "Ad Style Sheet");
define('CLASSES_NO_CUSTOM_CLASSES_DEFINED', "nulla consuetudine classes denfined-");
// Popup Messages:
define('CLASSES_DELETE_CLASS_CONFIRM_1_MSG', "Visne tu delere genus");
define('CLASSES_DELETE_CLASS_CONFIRM_2_MSG', "?");
define('CLASSES_DESCRIPTION_NOT_FOUND_MSG', "No records. Numquid non descriptio.");
define('CLASSES_DESCRIPTION_FOUND_MSG', "descriptionem");
define('CLASSES_COULD_NOT_UPDATE_DESCRIPTION_MSG', "Testimonium non invenitur. Numquid non update descriptio.");
define('CLASSES_DESCRIPTION_UPDATED_MSG', "updated Description");
define('CLASSES_STARTING_POPULATE_MSG', "Satus frequentare ...");
define('CLASSES_COPY_FROM_CLASS_BLANK_ERR', "Select a copy genus.");
define('CLASSES_COPY_TO_CLASS_BLANK_ERR', "Please enter a copy ad genus.");
define('CLASSES_COPY_CLASS_COMPLETE_MSG', "Class perfectum exemplar!");
define('CLASSES_COPY_CLASS_ERR', "Error occurrit genere conatur effingere.");
define('CLASSES_COPY_CLASS_TO_CLASS_ALREADY_EXISTS_ERR', "ERROR: iam genus effingo conaris.");
define('CLASSES_UPDATE_SORT_ORDER_COMPLETE_MSG', "Talem fuisse updated iubet.");
define('CLASSES_UPDATE_SORT_ORDER_UPDATE_ERR', "ERROR: adaequationis error talis ordo fuit.");
define('CLASSES_ADD_CLASS_COMPLETE_MSG', "Additum novum genus tuum.");
define('CLASSES_ADD_CLASS_ADD_ERR', "iam in database.");
define('CLASSES_DEFINE_SUBCLASS_COMPLETE_MSG', "Genus creatum vestras.");
define('CLASSES_DEFINE_SUBCLASS_DEFINE_ERR', "ERROR: creando novum genus erroris fuit.");
define('CLASSES_DELETE_CLASS_COMPLETE_MSG', "Class bene delevit.");
define('CLASSES_ADD_CLASS_CANNOT_BE_BLANK_MSG', "Class / Id nomen vestis possunt esse. Quaeso id nominis aut generis.");

///////////////////////// Edit Head Select /////////////////////////
// Buttons:
define('EDIT_HEAD_SELECT_HEADING', "Edit caput Code");

///////////////////////// Manage Head /////////////////////////
// Buttons:
define('MANAGE_HEAD_HEADING', "Caput Manage Codex");
define('MANAGE_HEAD_ADD_HEAD_BTN', "Add another caput Content");
// Console Text:
define('MANAGE_HEAD_ADD_HEAD_CONTENT', "Add caput Content");
define('MANAGE_HEAD_ASSIGN_HEAD_CONTENT_TO_PAGE', "Tribue caput Content to page");
define('MANAGE_HEAD_RENAME_HEAD_CONTENT', "Caput Rename Content");
define('MANAGE_HEAD_DELETE_HEAD_CONTENT', "Delete caput Content");
define('MANAGE_HEAD_SELECT_HEAD_CONTENT_TO_RENAME', "Select caput content ut rename");
define('MANAGE_HEAD_SELECT_HEAD_CONTENT_TO_DELETE', "Select caput contentus ad delete");
define('MANAGE_HEAD_NEW_NAME', "nomine");
// Popup Messages:
define('MANAGE_HEAD_DELETE_HEAD_CONFIRM_1_MSG', "Es vos certus vos volo ut delete");
define('MANAGE_HEAD_DELETE_HEAD_CONFIRM_2_MSG', "caput?");
define('MANAGE_HEAD_DELETED_1_MSG', "Caput");
define('MANAGE_HEAD_DELETED_2_MSG', "deletum.");
define('MANAGE_HEAD_DELETED_ERR', "Error: could not add caput");
define('MANAGE_HEAD_NO_HEADS_FOUND_ERR', "ERROR: no invenit principes.");
define('MANAGE_HEAD_NOT_FOUND_1_ERR', "non est.");
define('MANAGE_HEAD_NOT_FOUND_2_ERR', "return to page ad provinciam capitis.");
define('MANAGE_HEAD_ASSIGNED_1_MSG', "re fuerit assignata");
define('MANAGE_HEAD_ASSIGNED_2_MSG', "page.");
define('MANAGE_HEAD_ASSIGNED_1_ERR', "Error: could not assign");
define('MANAGE_HEAD_ASSIGNED_2_ERR', "ad");
define('MANAGE_HEAD_ASSIGNED_3_ERR', "page.");
define('MANAGE_HEAD_ADDED_1_MSG', "Caput");
define('MANAGE_HEAD_ADDED_2_MSG', "additum.");
define('MANAGE_HEAD_ADDED_ERR', "Error: could not add caput");
define('MANAGE_HEAD_PAGE_ALREADY_EXISTS_1_ERR', "Caput");
define('MANAGE_HEAD_PAGE_ALREADY_EXISTS_2_ERR', "iam est. Please enter a capite nomine.");
define('MANAGE_HEAD_ALREADY_ASSIGNED_1_ERR', "Dare non posse,");
define('MANAGE_HEAD_ALREADY_ASSIGNED_3_ERR', "page quia iam assignata.");

///////////////////////// Edit Favicon /////////////////////////
// Buttons:
define('EDIT_FAVICON_HEADING', "Edit Favicon");
define('EDIT_FAVICON_UPLOAD_BTN', "Upload");
// Console Text:
define('EDIT_FAVICON_UPLOAD_FAVICON', "Upload Favicon");
// Popup Messages:
define('EDIT_FAVICON_DELETE_FAVICON_CONFIRM', "Es vos certus vos volo ut delete favicon?");
define('EDIT_FAVICON_UPLOAD_SUCCESS_MSG', "Favicon est uploaded.");
define('EDIT_FAVICON_ONLY_ICONS_ALLOWED_MSG', "File icon nisi sit datum est uploaded, id est, myicon.ico. Please click");
define('EDIT_FAVICON_UPLOAD_FAIL_ERR', "Erat error discas lima.");

///////////////////////// Edit Page Titles /////////////////////////
// Buttons:
define('EDIT_PAGE_TITLES_HEADING', "Edit Page Titles");
// Console Text:
define('EDIT_PAGE_TITLES_REVISE_DEFAULT_PAGE_TITLE', "Default Revise Title Page");
define('EDIT_PAGE_TITLES_SELECT_PAGE', "Lego titulum pagina mutare");
define('EDIT_PAGE_TITLES_REVISE_SITE_TITLE', "Title Revise Site");
define('EDIT_PAGE_TITLES_SITE_TITLE_NOTE', "ad calcem paginae, si est,");
// Popup Messages:
define('EDIT_PAGE_TITLES_PAGE_TILE_SAVED_MSG', "Title Page fuerit, salvus erit.");

///////////////////////// Edit Meta Tags /////////////////////////
// Buttons:
define('EDIT_META_TAGS_HEADING', "Tags edit Meta");
// Console Text:
define('EDIT_META_TAGS_SELECT_PAGE', "Select a page");
define('EDIT_META_TAGS_KEYWORDS_NOTE', "Nota carmina uti &quot;,&quot; Key Phrases verbis separare amet.");
// Popup Messages:
define('EDIT_META_TAGS_META_TAGS_SAVED_MSG', "Meta tags sunt, salutem.");

///////////////////////// Delete Page or Blog /////////////////////////
// Buttons:
define('DELETE_PAGE_OR_BLOG_HEADING', "Delete Page vel Blog");
// Console Text:
define('DELETE_PAGE_OR_BLOG_SELECT_PAGE', "Lego delere vis page");
define('DELETE_PAGE_OR_BLOG_SELECT_BLOG', "Lego delere vis Blog");
// Popup Messages:
define('DELETE_PAGE_OR_BLOG_DELETE_BLOG_CONFIRM_1_MSG', "Numquid delere Visne");
define('DELETE_PAGE_OR_BLOG_DELETE_BLOG_CONFIRM_2_MSG', "?");
define('DELETE_PAGE_OR_BLOG_DELETE_PAGE_CONFIRM_1_MSG', "Numquid vis ut delete amet");
define('DELETE_PAGE_OR_BLOG_DELETE_PAGE_CONFIRM_2_MSG', "page?");
define('DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_1_MSG', "Numquid reducere Visne");
define('DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_2_MSG', "Plugin?");

///////////////////////// Copy/Raname Select Page /////////////////////////
// Buttons:
define('COPY_RENAME_PAGE_HEADING', "Copy vel Rename Pages");
define('COPY_RENAME_PAGE_COPY_RENAME_BTN', "Copy / rename");
// Console Text:
define('COPY_RENAME_PAGE_DISCARD_TEMPLATE_NOTE', "Relinquere template et vetus paginam creare");
define('COPY_RENAME_PAGE_RENAME_PAGE_LINK_NOTE', "Note: Quae tu creasti Renaming page nexus haud mutabo. Menu a egestas sit amet sponte vos postulo muto aliquid paginae quae nexus nominis mentionem edit.");

///////////////////////// Copy/Raname Page /////////////////////////
// Buttons:
define('COPY_RENAME_PAGE_OVERWRITE_DESTINATION_BTN', "overwrite destination");
define('COPY_RENAME_PAGE_OVERWRITE_DESTINATION_RETAIN_TEMPLATE_BTN', "Overwrite retinere, sed destinatio destinatum contentus Template");
define('COPY_RENAME_PAGE_OVERWRITE_DESTINATION_CREATE_NEW_TEMPLATE_BTN', "Overwrite in finem creare novum contentus Template per source site lego bene");
define('COPY_RENAME_PAGE_CANCEL_COPY_BTN', "Cancel ad exemplar et exemplum / console rename");
// Console Text:
define('COPY_RENAME_PAGE_PAGE_ALREADY_EXISTS', "iam est. Quid tibi vis faciam?");
// Popup Messages:
define('COPY_RENAME_PAGE_FORGOT_TO_SELECT_PAGE_TO_RENAME_1_MSG', "X! Index renominationum page oblitus es eligere.");
define('COPY_RENAME_PAGE_FORGOT_TO_SELECT_PAGE_TO_RENAME_2_MSG', "Index renominationum page eligenda sit forma.");
define('COPY_RENAME_PAGE_FORGOT_TO_ENTER_NEW_PAGE_NAME_1_MSG', "X! Confiteantur tibi nomen novum page intrare.");
define('COPY_RENAME_PAGE_FORGOT_TO_ENTER_NEW_PAGE_NAME_2_MSG', "et novas pagina nomen.");
define('COPY_RENAME_PAGE_COPY_ONTO_SELF_1_MSG', "Paginam super aemulari non licet ipsum. (Nisi dilexisset template deponere veterem et novam creare.)");
define('COPY_RENAME_PAGE_COPY_ONTO_SELF_2_MSG', "et novas pagina nomen.");
define('COPY_RENAME_PAGE_ERROR_OPENING_NEW_PAGE_ERR', "Error aperuit novum page lima. Administrator contact vestri ratio.");
define('COPY_RENAME_PAGE_ERROR_UPDATING_PAGE_NAME_REFERENCES_ERR', "Error in References adaequationis Page name novus page lima. Administrator contact vestri ratio.");
define('COPY_RENAME_PAGE_ERROR_CLOSING_NEW_PAGE_AFETR_REFERENCE_UPDATE_ERR', "Error in References nomen operti page lima page. Administrator contact vestri ratio.");
define('COPY_RENAME_PAGE_TO_RETURN_TO_COPY_RENAME_CONSOLE', "ad exemplar / renominationum consolatorium.");
define('COPY_RENAME_PAGE_RENAME_NEW_PAGE_ALREADY_EXISTS_1_ERR', "in page");
define('COPY_RENAME_PAGE_RENAME_NEW_PAGE_ALREADY_EXISTS_2_ERR', "iam est. Vos can rename non");
define('COPY_RENAME_PAGE_RENAME_NEW_PAGE_ALREADY_EXISTS_3_ERR', "et nomen intrare alium finem.");
define('COPY_RENAME_PAGE_UNKNOWN_ERROR_ERR', "Quam vis quaedam imitari non possumus utrum vel create. Ingredere et eligere operationem album.");
define('COPY_RENAME_PAGE_RENAME_OLD_PAGE_NOT_FOUND_ERR', "non inventum. Administrator contact vestri ratio.");
define('COPY_RENAME_PAGE_ERROR_RENAMING_PAGE_ERR', "Error file renaming. Administrator contact vestri ratio.");
define('COPY_RENAME_PAGE_ERROR_OPENING_ORIGINAL_PAGE_ERR', "Opening page original file Error. Administrator contact vestri ratio.");
define('COPY_RENAME_PAGE_ERROR_WRITING_TO_NEW_PAGE_ERR', "Error Scriptura contenti New page lima. Administrator contact vestri ratio.");
define('COPY_RENAME_PAGE_ERROR_CLOSING_NEW_PAGE_ERR', "Error operti New page lima. Administrator contact vestri ratio.");
define('COPY_RENAME_PAGE_CANT_READ_ERR', "Aut non legistis");

///////////////////////// Restore Page /////////////////////////
// Buttons:
define('RESTORE_PAGE_HEADING', "Redde Page");
define('RESTORE_PAGE_SHOW_CONTENT_BTN', "Show Content");
define('RESTORE_PAGE_SHOW_CODE_BTN', "Show Code");
// Console Text:
define('RESTORE_PAGE_SELECT_PAGE', "Lego pagina reficiendum");
define('RESTORE_PAGE_DELETE_FROM_HISTORY', "Delete a Historiarum");
// Popup Messages:
define('RESTORE_PAGE_DELETE_BACKUP_CONFIRM_1_MSG', "Es vos certus vos volo ut <b>delete</b>");
define('RESTORE_PAGE_DELETE_BACKUP_CONFIRM_2_MSG', "page tergum historia?");
define('RESTORE_PAGE_RESTORE_PAGE_CONFIRM_1_MSG', "Visne tu <b>restituere</b>");
define('RESTORE_PAGE_RESTORE_PAGE_CONFIRM_2_MSG', "page?");

///////////////////////// Add Plugin to Page /////////////////////////
// Buttons:
define('ADD_PLUGIN_TO_PAGE_HEADING', "Install Plugin in Page");
define('ADD_PLUGIN_TO_PAGE_SELECT_PAGE_HEADING', "Select Page");
define('ADD_PLUGIN_TO_PAGE_SELECT_PLUGIN_HEADING', "Select Plugin");
// Console Text:
define('ADD_PLUGIN_TO_PAGE_PAGE_SELECTED', "lego page");
define('ADD_PLUGIN_TO_PAGE_PLUGIN_SELECTED', "lego plugin");
// Popup Messages:
define('ADD_PLUGIN_TO_PAGE_PLUGIN_HAS_BEEN_ADDED_TO_PAGE_1_MSG', "quod");
define('ADD_PLUGIN_TO_PAGE_PLUGIN_HAS_BEEN_ADDED_TO_PAGE_2_MSG', "has been inserted in a plugin");
define('ADD_PLUGIN_TO_PAGE_PLUGIN_HAS_BEEN_ADDED_TO_PAGE_3_MSG', "page.");
define('ADD_PLUGIN_TO_PAGE_PAGE_OR_PLUGIN_NOT_SELECTED_1_MSG', "X! Et oblitus es eligere page / aut plugin.");
define('ADD_PLUGIN_TO_PAGE_PAGE_OR_PLUGIN_NOT_SELECTED_2_MSG', "scriptis et plugin pagina.");
define('ADD_PLUGIN_TO_PAGE_ERROR_OPENING_PAGE_FILE_ERR', "Error opening page lima. Administrator contact vestri ratio.");
define('ADD_PLUGIN_TO_PAGE_ERROR_UPDATING_PAGE_FILE_ERR', "Error adaequationis page lima. Administrator contact vestri ratio.");
define('ADD_PLUGIN_TO_PAGE_ERROR_CLOSING_PAGE_FILE_ERR', "Error operti page lima. Administrator contact vestri ratio.");
define('ADD_PLUGIN_TO_PAGE_RETURN_TO_INSERT_PLUGIN_INTO_PAGE_CONSOLE_MSG', "interserunt, ut ad rem redeam, in plugin page consolatorium.");
define('ADD_PLUGIN_TO_PAGE_COULD_NOT_RENAME_MSG', "Numquid non rename");

///////////////////////// Mange Page Access /////////////////////////
// Buttons:
define('MANAGE_PAGE_ACCESS_HEADING', "Restricted Manage Pages &amp; Website Users");
define('MANAGE_PAGE_ACCESS_ADD_LOGIN_FIELDS_BTN', "Add User Login <br /> Tabula regiones");
define('MANAGE_PAGE_ACCESS_ASSIGN_WELCOME_MESSAGE_PAGE_BTN', "Tribue Welcome Message <br /> Page to Table Disputatio");
// Console Text:
define('MANAGE_PAGE_ACCESS_RESTRICT_PAGE_ACCESS', "Page Termino Obvius");
define('MANAGE_PAGE_ACCESS_APPROVE_ACCESSTO_USERS', "Obvius ad probare Users");
define('MANAGE_PAGE_ACCESS_USER_TABLE_SETUP', "User Table Setup");
define('MANAGE_PAGE_ACCESS_SHOW_LOGIN_LINKS_ALWAYS', "Show Login <br /> semper Links");
define('MANAGE_PAGE_ACCESS_REQUIRE_LOGIN', "requirit Login");
define('MANAGE_PAGE_ACCESS_LOGIN_PAGE', "Login");
define('MANAGE_PAGE_ACCESS_MESSAGE_PAGE', "Nuntius Page");
define('MANAGE_PAGE_ACCESS_FIRST_LAST', "(Primum, ultimum)");
define('MANAGE_PAGE_ACCESS_OPTIONAL', "(Optional)");
define('MANAGE_PAGE_ACCESS_ADDITIONAL_FORMS_NOTE', "Per formam User addi solent (s) creata website. Ut etiam infra praeter formae sunt de users in a site backend Aura Website conditor et magistratus virtutis users.");
// Popup Messages:
define('MANAGE_PAGE_ACCESS_DELETE_USER_CONFIRM_1_MSG', "Visne tu delere usoris");
define('MANAGE_PAGE_ACCESS_DELETE_USER_CONFIRM_2_MSG', "?");
define('MANAGE_PAGE_ACCESS_USER_DELETED_1_MSG', "Disputatio");
define('MANAGE_PAGE_ACCESS_USER_DELETED_2_MSG', "deletum");
define('MANAGE_PAGE_ACCESS_DELETE_ACCESS_LEVEL_CONFIRM_1_MSG', "Visne tu aequum aditum delere");
define('MANAGE_PAGE_ACCESS_DELETE_ACCESS_LEVEL_CONFIRM_2_MSG', "?");
define('MANAGE_PAGE_ACCESS_LOCATING_PAGE_RESTRICTIONS_MSG', "Locating modum page ...");
define('MANAGE_PAGE_ACCESS_COULD_NOT_UPDATE_PAGE_RESTRICTIONS_MSG', "Testimonium non invenitur. Page update angustiis non poterat.");
define('MANAGE_PAGE_ACCESS_PAGE_RESTRICTIONS_UPDATED_MSG', "Page modum updated");
define('MANAGE_PAGE_ACCESS_UPDATING_PAGE_RESTRICTIONS_MSG', "Modum adaequationis page ...");
define('MANAGE_PAGE_ACCESS_COULD_NOT_UPDATE_USER_STATUS_MSG', "Testimonium non invenitur. Numquid non update User Status.");
define('MANAGE_PAGE_ACCESS_USER_STATUS_UPDATED_MSG', "User Status updated");
define('MANAGE_PAGE_ACCESS_UPDATING_USER_STATUS_MSG', "Adaequationis User Status ...");
define('MANAGE_PAGE_ACCESS_COULD_NOT_MODIFY_TABLE_MSG', "Mensam mutare posset,");
define('MANAGE_PAGE_ACCESS_FIELDS_ADDED_TO_TABLE_MSG', "Agri ad mensam,");
define('MANAGE_PAGE_ACCESS_ADDING_FIELDS_TO_TABLE_MSG', "Addens in regione mensae ...");
define('MANAGE_PAGE_ACCESS_WELCOME_MESSAGE_PAGE_ADDED_TO_TABLE_MSG', "Welcome message ad mensam page");
define('MANAGE_PAGE_ACCESS_ADDING_WELCOME_MESSAGE_PAGE_TO_TABLE_MSG', "Nuntius venit ad mensam addens page ...");
define('MANAGE_PAGE_ACCESS_COULD_NOT_ADD_DELETE_ACCESS_LEVEL_MSG', "Numquid non addere vel delete accessum gradu.");
define('MANAGE_PAGE_ACCESS_ACESS_LEVEL_RECORDS_MODIFIED_MSG', "Obvius mutatio gradu Records");
define('MANAGE_PAGE_ACCESS_CHANGING_ACCESS_LEVELS_MSG', "Transfiguratus accessum gradus ...");
define('MANAGE_PAGE_ACCESS_LOCATING_ACCESS_LEVELS_MSG', "Locating accessum gradus ...");
define('MANAGE_PAGE_ACCESS_LOCATING_USERS_MSG', "Locating users ...");
define('MANAGE_PAGE_ACCESS_REQUIRED_FIELDS_MSG', "Planto certus vos es usura, quia forma est, habet agrum users nomina &#39;email&#39;, &#39;UserID et Password. Si usus fuit mensa pro recreatione delegisti plugin formam, tunc est in mensa agros.");
define('MANAGE_PAGE_ACCESS_RETRIEVING_PAGE_RESTRICTIONS_MSG', "Retrieving modum page ...");
define('MANAGE_PAGE_ACCESS_RETRIEVING_ACCESS_LEVELS_MSG', "Retrieving accessum gradus ...");
define('MANAGE_PAGE_ACCESS_RETRIEVING_USERS_MSG', "Retrieving users ...");
define('MANAGE_PAGE_ACCESS_ADDING_LOGIN_FIELDS_TO_TABLE_MSG', "Consummatio Login agris ad mensam ...");
define('MANAGE_PAGE_ACCESS_ASSIGNING_WELCOME_MESSAGE_PAGE_TO_TABLE_MSG', "Nuntius venit ad mensam assignari page ...");
define('MANAGE_PAGE_ACCESS_ADDING_ACCESS_LEVEL_MSG', "Adding accessu gradu ...");
define('MANAGE_PAGE_ACCESS_REMOVING_ACCESS_LEVEL_MSG', "Amotio accessum gradu ...");
define('MANAGE_PAGE_ACCESS_NEW_USER_NOT_ADDED_ERR', "An error occurrit. User non additur nova.");
define('MANAGE_PAGE_ACCESS_NEW_USER_CREATED_1_MSG', "usoris");
define('MANAGE_PAGE_ACCESS_NEW_USER_CREATED_2_MSG', "creatus in password");
define('MANAGE_PAGE_ACCESS_NEW_USER_CREATED_3_MSG', "et accessum ad gradus");
define('MANAGE_PAGE_ACCESS_NEW_USER_CREATED_4_MSG', "quia");
define('MANAGE_PAGE_ACCESS_NEW_USER_CREATED_5_MSG', "cum Email");
define('MANAGE_PAGE_ACCESS_PASSWORD_CHANGED_1_MSG', "Tessera usoris");
define('MANAGE_PAGE_ACCESS_PASSWORD_CHANGED_2_MSG', "non est mutatio, ut");
define('MANAGE_PAGE_ACCESS_USER_CHANGED_1_MSG', "Disputatio");
define('MANAGE_PAGE_ACCESS_USER_CHANGED_2_MSG', "quae cum accesserit mutatio gradu");
define('MANAGE_PAGE_ACCESS_USER_CHANGED_3_MSG', "Et nomen,");
define('MANAGE_PAGE_ACCESS_USER_CHANGED_4_MSG', "et de Email");
define('MANAGE_PAGE_ACCESS_NO_DATA_FOUND_FOR_USER_ERR', "ERROR: no data est pro user");
define('MANAGE_PAGE_ACCESS_NO_TABLE_SELECTED_ERR', "Habebis a mensa User Login aditus lectus eget si vis esse. Select a user mensa conare denuo.");
define('MANAGE_PAGE_ACCESS_NO_LOGIN_PAGE_SELECTED_ERR', "Tu si vis habere lectus eget Login obvius login pagina. Select a login tum conare denuo. Si non sunt paginae Login album, primum facit tribulationem login login plugin. Nomen login continent &#39;login.");


///////////////////////// Manage Page Attributes /////////////////////////
// Buttons:
define('MANAGE_PAGE_ATTRIBUTES_HEADING', "Page Manage attributa");
define('MANAGE_PAGE_ATTRIBUTES_TEMPLATE_HEADING', "Template Layout");
// Console Text:
define('MANAGE_PAGE_ATTRIBUTES_PAGE_ATTRIBUTES', "Page attributa");
define('MANAGE_PAGE_ATTRIBUTES_USE_PAGE_TABLE_STRUCTURES', "Use Page Table Structures");
define('MANAGE_PAGE_ATTRIBUTES_USE_PAGE_TABLE_STRUCTURES_FOR_MOBILE', "Uti Page Table rationes Mobile");
define('MANAGE_PAGE_ATTRIBUTES_CALL_BODY_ONLOAD_FUNCTION', "OnLoad vocant corpus Muneris");
define('MANAGE_PAGE_ATTRIBUTES_DISABLE_SITE_STYLES_WHEN_EDITING', "Disable Site Styles cum Editing");
define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_HEAD', "Insert in Custom Default Caput capitis");
define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_HEADER', "Insert in Default Header Custom Header");
define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_TOP', "Insert in Top Default Custom Top");
define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_LEFT', "Insert in Custom Default Reliquit Left");
define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_RIGHT', "Insert in Custom Default iure Ius");
define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_BOTTOM', "Default Insert in imo imo Custom");
define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_FOOTER', "Insert in Default Footer Custom Footer");
// Popup Messages:
define('MANAGE_PAGE_ATTRIBUTES_ERROR_RETRIEVING_PAGE_ATTRIBUTES_ERR', "Erroris page reparandus erat attributa.");
define('MANAGE_PAGE_ATTRIBUTES_PAGE_ATTRIBUTES_SAVED_MSG', "Adspectum graciliorem attributa salvari potuisset.");
define('MANAGE_PAGE_ATTRIBUTES_ERROR_SAVING_PAGE_ATTRIBUTES_ERR', "Salvo page attributa fuit error.");
define('MANAGE_PAGE_ATTRIBUTES_ERROR_ONLOAD_ERR', "Si OnLoad vocant corpus Muneris est prohibitus, non munere vestis.");

///////////////////////// Upload Template /////////////////////////
// Buttons:
define('UPLOAD_TEMPLATE_HEADING', "Upload Template");
// Console Text:
define('UPLOAD_TEMPLATE_CONFIRM_MSG', "Visne tu te novi fasciculos template? Quae autem reparare mutationes situs et irrevocabile. Et optio detur, utrum velis pagina contentus, sed proposito terminus area contentus erit reponi.");
define('RERUN_WIZARD_RUN_WIZARD_CONFIRM_MSG', "Numquid currere Visne iterum veneficus? Quae autem reparare mutationes situs et irrevocabile. Et optio detur, utrum velis pagina contentus, sed proposito terminus area contentus erit reponi.");
define('UPLOAD_TEMPLATE_BUILDING_SITE_MSG', "Template .... cum aedificaretur");
define('UPLOAD_TEMPLATE_WHEN_COMPLETE_SCROLL_TO_BOTTOM_MSG', "Cum completi per totum librum permanere.");
define('UPLOAD_TEMPLATE_ALLOWED_FILE_TYPE_MSG', "Tantum gzipped tar file uploaded liceat, id est, template_105.tgz &#39;vel&#39; template_26.tar.gz. Please click");
define('UPLOAD_TEMPLATE_COPYING_USER_FILES_MSG', "Effingo files User ...");
define('UPLOAD_TEMPLATE_COPYING_PAGES_MSG', "Effingo pages ...");
define('UPLOAD_TEMPLATE_COPYING_IMAGES_MSG', "Effingo images ...");
define('UPLOAD_TEMPLATE_COPYING_CSS_MSG', "Effingo ins ...");
define('UPLOAD_TEMPLATE_COPYING_MEDIA_MSG', "Effingo media ...");
define('UPLOAD_TEMPLATE_COPYING_FLASH_MSG', "Effingo Mico ...");
define('UPLOAD_TEMPLATE_COPYING_SCRIPTS_MSG', "Effingo scriptor ...");
define('UPLOAD_TEMPLATE_COPYING_XML_MSG', "Effingo XML ...");
define('UPLOAD_TEMPLATE_UNABLE_TO_OPEN_DOC_ROOT_ERR', "Unable ut patefacio radix documentum.");
define('UPLOAD_TEMPLATE_COULD_NOT_RENAME_ERR', "Numquid non rename");
define('UPLOAD_TEMPLATE_CANT_CREATE_ERR', "Non potest");
define('UPLOAD_TEMPLATE_ERROR_UPLOADING_FILE_ERR', "Erat error discas lima.");
define('UPLOAD_TEMPLATE_TO_CONTINUE_MSG', "continere.");
define('UPLOAD_TEMPLATE_SQL_FILE_MSG', "SQL file ...");
define('UPLOAD_TEMPLATE_SQL_FILE_NAME_NOT_DEFINED_ERR', "Fatalem errorem SQL lima nomen non definitur.");
define('UPLOAD_TEMPLATE_SQL_MSG', "SQL ...");
define('UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG', "versu (s) affectus.");
define('UPLOAD_TEMPLATE_SELECT_TEMPLATE_FROM_YOUR_COMPUTER', "Lego template vis install a computer:");
define('UPLOAD_TEMPLATE_DELETE_ALL_PAGES', "Delete pages");
// Popup Messages:
define('UPLOAD_TEMPLATE_DELETE_ALL_PAGES_CONFIRM_MSG', "Visne tu te omnes delere page impleo?");
define('UPLOAD_TEMPLATE_UPLOADING_TEMPLATE_PLEASE_WAIT_MSG', "Uploading template, please wait ...");
define('UPLOAD_TEMPLATE_UPLOADING', "Uploading template, please wait ...");

///////////////////////// Admin Function Select /////////////////////////
// Buttons:
define('ADMIN_FUNCTION_SELECT_HEADING', "Users Manage &amp; Site Options");
define('ADMIN_FUNCTION_SELECT_MANAGE_USERS_BTN', "Users Manage");
define('ADMIN_FUNCTION_SELECT_CHANGE_SITE_OPTIONS_BTN', "Bene mutantur Site");
define('ADMIN_FUNCTION_SELECT_RESTRICT_PAGE_EDITING_ACCESS_BTN', "Editing Page Termino Obvius");
define('ADMIN_FUNCTION_SELECT_GENERATE_SITE_MAP_BTN', "Generare Site Map");
define('ADMIN_FUNCTION_SELECT_PRUNE_PAGE_EDIT_BACKUP_TABLE_BTN', "Edit Page Tergum Table putabis");
define('ADMIN_FUNCTION_SELECT_PRUNE_BACKUP_FILES_BTN', "About putabis, Site Map, <br /> edit lima tergum, et <br /> JavaScript menu tergum lima");
define('ADMIN_FUNCTION_SELECT_CLEAR_CUSTOM_CLASSES_BTN', "About Omnia Custom Classes Nubila");
define('ADMIN_FUNCTION_SELECT_INSTALL_PLUGIN_BTN', "Plugin Install");
define('ADMIN_FUNCTION_SELECT_RECALL_PLUGIN_BTN', "Recordare Plugin");
define('ADMIN_FUNCTION_SELECT_INSTALL_UPDATE_BTN', "Install Update");
define('ADMIN_FUNCTION_SELECT_RUN_SQL_BTN', "run SQL");
define('ADMIN_FUNCTION_SELECT_SHOW_SERVER_INFO_BTN', "Show Server");
define('ADMIN_FUNCTION_SELECT_DEACTIVATE_WEBSITE_BTN', "De activate Website");
define('ADMIN_FUNCTION_SELECT_ACTIVATE_WEBSITE_BTN', "Website activate");
// Console Text:
define('ADMIN_FUNCTION_SELECT_PRUNE_PAGE_EDIT_BACKUP_TABLE_TO', "Edit Page putabis tergum ad mensam,");
define('ADMIN_FUNCTION_SELECT_SELECT_PLUGIN_TO_RECALL', "Lego in plugin vis revocare");
// Popup Messages:
define('ADMIN_FUNCTION_SELECT_DEACTIVATE_SITE_CONFIRM_MSG', "Vis ad vestri site eam lineam?");
define('ADMIN_FUNCTION_SELECT_ACTIVATE_SITE_CONFIRM_MSG', "Vis ad vestri site vixisti");
define('ADMIN_FUNCTION_SELECT_BACKUP_FILES_HAVE_BEEN_PRUNED_MSG', "CSS, Site Map, et JavaScript menu tergum ut lima est mundi.");

///////////////////////// Manage Users /////////////////////////
// Buttons:
define('MANAGE_USERS_HEADING', "Users Manage");
// Console Text:
define('MANAGE_USERS_SSL_NOT_PRESENT_WARNING', "<b>CAVE:</b> visum tibi esse, cum in unencrypted circa hoc consolatorium. Si vos additis commendatur uti uel mutare Tesserae encrypted nexu. Ut switch ut an encrypted nexu, click");
define('MANAGE_USERS_INVALID_CERTIFICATE_NOTE', "Nota SSL testimonium non valet. Quod si ita sit, et usque ad encrypted nexu accipitis Quisque elit. Nonnulli etiam libellorum SSL elit non servientibus, ita ut non posset hanc encrypted consolantur. Si, iustus click in pagina non operatur ad ipsum.");
// Popup Messages:
define('MANAGE_USERS_DELETE_USER_CONFIRM_1_MSG', "Numquid delere Visne usoris");
define('MANAGE_USERS_DELETE_USER_CONFIRM_2_MSG', "?");
define('MANAGE_USERS_USER_DELETED_1_MSG', "Disputatio");
define('MANAGE_USERS_USER_DELETED_2_MSG', "deletum");
define('MANAGE_USERS_NO_USERS_FOUND_ERR', "ERROR: no users found");
define('MANAGE_USERS_NO_DATA_FOUND_FOR_USER_ERR', "ERROR: no data est pro user");
define('MANAGE_USERS_USER_NOT_ADDED_ERR', "An error occurrit. User non additur nova.");
define('MANAGE_USERS_NEW_USER_ADDED_1_MSG', "usoris");
define('MANAGE_USERS_NEW_USER_ADDED_2_MSG', "creatus in password");
define('MANAGE_USERS_NEW_USER_ADDED_3_MSG', "et accessum ad gradus");
define('MANAGE_USERS_NEW_USER_ADDED_4_MSG', "quia");
define('MANAGE_USERS_NEW_USER_ADDED_5_MSG', "cum Email");
define('MANAGE_USERS_PASSWORD_CHANGED_1_MSG', "Tessera usoris");
define('MANAGE_USERS_PASSWORD_CHANGED_2_MSG', "non est mutatio, ut");
define('MANAGE_USERS_USER_MODIFIED_1_MSG', "Disputatio");
define('MANAGE_USERS_USER_MODIFIED_2_MSG', "quae cum accesserit mutatio gradu");
define('MANAGE_USERS_USER_MODIFIED_3_MSG', "Et nomen,");
define('MANAGE_USERS_USER_MODIFIED_4_MSG', "et de Email");
define('MANAGE_USERS_NO_TABLE_TO_ADD_USER_TO_1_ERR', "Eligere oportet primum mensam apponere user.");
define('MANAGE_USERS_NO_TABLE_TO_ADD_USER_TO_2_ERR', "eligere mensa conare denuo.");
define('MANAGE_USERS_USER_ALREADY_EXISTS_ERR', "nomen usoris intrare alium.");
define('MANAGE_USERS_NO_TABLE_TO_CHANGE_USER_PASSWORD_ERR', "Eligere oportet primum commutata mensam signum a user.");
define('MANAGE_USERS_NO_TABLE_TO_DELETE_USER_FROM_ERR', "Eligere oportet primum ut delete a user de mensa.");

///////////////////////// Manage SIte Options /////////////////////////
// Buttons:
define('MANAGE_SITE_OPTIONS_HEADING', "Bene mutantur Site");
// Console Text:
// Popup Messages:
define('MANAGE_SITE_OPTIONS_OPTIONS_SAVED_MSG', "Et bene salvari.");
define('MANAGE_SITE_OPTIONS_ERROR_SAVING_OPTIONS_ERR', "Bene conservata fuit error.");

///////////////////////// Restrict Page Editing Access /////////////////////////
// Buttons:
define('RESTRICT_PAGE_EDITING_HEADING', "Restricted Access ad paginas pro Termino Users");
// Console Text:
// Popup Messages:
define('RESTRICT_PAGE_EDITING_RESTRICTIONS_SAVED_MSG', "Page modum salvari.");

///////////////////////// Generate Site Map /////////////////////////
// Buttons:
define('GENERATE_SITE_MAP_HEADING', "Generare Site Map");
// Console Text:
define('GENERATE_SITE_MAP_GENERATING', "Generandi ... Site Map");
define('GENERATE_SITE_MAP_COULD_NOT_RENAME_1_ERR', "Numquid non rename");
define('GENERATE_SITE_MAP_COULD_NOT_RENAME_2_ERR', "ut");
define('GENERATE_SITE_MAP_ERROR_CREATING_SITEMAP_ERR', "Error creatng Site map.");
define('GENERATE_SITE_MAP_SITEMAP_REBUILD_COMPLETE', "Sitemap aedificare completum!");
define('GENERATE_SITE_MAP_SITEMAP_CREATION_COMPLETE', "Sitemap omni creaturae!");
define('GENERATE_SITE_MAP_ROBOT_FILE_CREATED', "Robot file creavit!");
define('GENERATE_SITE_MAP_CANT_CREATE_ERR', "Non potest");

///////////////////////// Install Plugin /////////////////////////
// Buttons:
define('INSTALL_PLUGIN_HEADING', "Plugin Install");
// Console Text:
define('INSTALL_PLUGIN_PLEASE_ENTER_PASSWORD_FOR_ADMIN', "Ratio enim ignoro PDF");
define('INSTALL_PLUGIN_SELECT_PLUGIN_FROM_YOUR_COMPUTER', "Lego plugin vis install a computer");
define('INSTALL_PLUGIN_INSTALLING_PLUGIN', "Installing plugin ....");
define('INSTALL_PLUGIN_WRONG_FILE_TYPE_MSG', "Sed zipped files aut bitumen gzipped file uploaded liceat, id est, plugin.zip &#39;vel&#39; plugin.tgz &#39;vel&#39; plugin.tar.gz. Please click");
define('INSTALL_PLUGIN_EXTRACTING_FILES', "Extracting files ...");
define('INSTALL_PLUGIN_ERROR_EXTRACTING_FILES_1_ERR', "Erat a zip lima lima extrahendis error.");
define('INSTALL_PLUGIN_ERROR_EXTRACTING_FILES_1A_ERR', "Fuit de errore extrahendis tar.gz lima lima.");
define('INSTALL_PLUGIN_ERROR_EXTRACTING_FILES_1B_ERR', "Tar, abstrahendo ab errore fuit lima lima.");
define('INSTALL_PLUGIN_COPYING_FILES', "Effingo Lima ...");
define('INSTALL_PLUGIN_PLUGIN_INSTALLATION_COMPLETE', "Plugin comlplete installation est.");
define('INSTALL_PLUGIN_ADD_NEW_BUTTON_TO_MENU_MSG', "add to New plugin ipsum ut menu.");
define('INSTALL_PLUGIN_ERROR_UPLOADING_FILE_ERR', "Erat error discas lima.");
// Popup Messages:

///////////////////////// Install Update /////////////////////////
// Buttons:
define('INSTALL_UPDATE_HEADING', "Install Update");
// Console Text:
define('INSTALL_UPDATE_SELECT_UPDATE_FROM_YOUR_COMPUTER', "Lego vis install a update vestri computer");
define('INSTALL_UPDATE_INSTALLING_UPDATE', "Installing update ....");
define('INSTALL_UPDATE_WRONG_FILE_TYPE_MSG', "Sed zipped gzipped files aut bitumen file uploaded liceat, id est, breeze_update_x.x.xx.tgz &#39;vel&#39; breeze_update_x.x.xx.tar.gz &#39;vel&#39; breeze_update_x.x.xx.zip. Please click");
define('INSTALL_UPDATE_UPDATE_INSTALLATION_COMPLETE', "Update installation est universa.");
define('INSTALL_UPDATE_REFRESH_MAIN_MENU', "ad curare pelagus menu.");
// Popup Messages:
define('INSTALL_UPDATE_NEW_VERSION_AVAILABLE', "Website venti nova praesto est conditor. Update nunc vis? <br /><p class='medium_message' style='text-align:left;'> Haec erit vobis aperire everytime usque in Aura est updated. Si plus quam versio antiqua Latina Aura te prohibere necesse nuntiis ad incrementum caperet istas updates semi- tincidunt. </p>");
define('INSTALL_UPDATE_VERSION_ERROR_ERR', "Latae update facere cupiebat, sed est inter priorem mismatch Vulgata versione Latina file database poema poematis.");

///////////////////////// Run SQL /////////////////////////
// Buttons:
define('RUN_SQL_HEADING', "run SQL");
// Console Text:
define('RUN_SQL_PASTE_SQL_MSG', "Crustulum vel intra SQL quod (est) super fenestram. Tunc click &quot;Add&quot;.");
define('RUN_SQL_SQL_COMMAND_DELIMITERS_NOTE', "Nota: unusquisque per a SQL signo terminatur, quod est mandatum (). Incipiens linearum (-) seu (//) Comments ut dicetur.");

///////////////////////// Javascript Menu Params and Styles /////////////////////////
// Popup Messages:
define('JS_MENU_PARAM_NO_PACAMETERS_1_ERR', "Set non parametri sunt.");
define('JS_MENU_PARAM_NO_PACAMETERS_2_ERR', "ad replendum et pretium augue.");
define('JS_MENU_STYLES_ERROR_SAVING_RECORD_ERR', "Error occurrit trying ad salvandas testimonium");
define('JS_MENU_CODE_REMOVE_CODE_CONFIRM_1_MSG', "Numquid vis tollere certus de codice JavaScript Menu");
define('JS_MENU_CODE_REMOVE_CODE_CONFIRM_2_MSG', "?");

///////////////////////// Options /////////////////////////
// Strings:
define('OPTIONS_TEMPLATE', "Template");
define('OPTIONS_FORCE_PAGE_NAME_TO_LOWER_CASE', "Nomine inferiorum virium Case");
define('OPTIONS_ENABLE_WIZARD', "enable Veneficus");
define('OPTIONS_RUN_WIZARD_LOCAL', "Local Run Carmina (Check if Template Demo Repository modo installation es et aura in eadem server.)");
define('OPTIONS_ENABLE_FILE_MANAGER_FOR_RESTRICTED_USERS', "File Disable User Procurator pro Restricted");
define('OPTIONS_ACTIVATE_NEW_USERS_AUTOMATICALLY', "Automatically New User Strenuus");
define('OPTIONS_USE_TABLE_STRUCTURES', "Use traba compages");
define('OPTIONS_USE_TABLE_STRUCTURES_ON_MOBILE', "Uti traba compages in Mobile");
define('OPTIONS_CREATE_ACCOUNT_LINK_TEXT', "Create Account Link Text");
define('OPTIONS_LOGIN_LINK_TEXT', "Login Link Text");
define('OPTIONS_MY_ACCOUNT_LINK_TEXT', "My Account Link Text");
define('OPTIONS_LOGOUT_LINK_TEXT', "PP Link Text");
define('OPTIONS_CREATE_ACCOUNT_LINK', "Create Account Link Text");
define('OPTIONS_LOGIN_LINK', "Login Link Text");
define('OPTIONS_MY_ACCOUNT_LINK', "My Account Link Text");
define('OPTIONS_LOGOUT_REDIRECT_OVERRIDE', "Redirect PP Override");
define('OPTIONS_EDITOR_SOURCE_VIEW_THEME', "Editor View Source Theme");
define('OPTIONS_BREEZE_WEBSITE_BUILDER_THEME', "Website aura conditor Theme");
define('OPTIONS_LOCKOUT_CLEAR_ALL_CUSTOM_CSS_CLASSES', "About Omnia Custom Classes Lockout Nubila");
define('OPTIONS_LOCKOUT_COPY_STYLE_SHEET_TO_MOBILE', "Copy Style Sheet Lockout est Mobile");

////////////////////// Manage Custom Fonts /////////////////////////////////////
// Buttons:
define('MANAGE_CUSTOM_FONTS_HEADING', "Nam semper lacinia blandit Manage");
// Console Text:
define('MANAGE_CUSTOM_FONTS_ADD_FONT', "Add Font");
define('MANAGE_CUSTOM_FONTS_DELETE_FONT', "Delete Font");
define('MANAGE_CUSTOM_FONTS_NO_FONTS', "nulla consuetudine fonts-");
define('MANAGE_CUSTOM_FONTS_STRETCH', "Extendam");
define('MANAGE_CUSTOM_FONTS_STYLE', "Style");
define('MANAGE_CUSTOM_FONTS_WEIGHT', "Weight");
// Popup Messages:
define('MANAGE_CUSTOM_FONTS_GET_FONTS_MSG', "Questus Pelvis ...");
define('MANAGE_CUSTOM_FONTS_GET_FONTS_COMPLETE_MSG', "Populating Pelvis perfecta.");
define('MANAGE_CUSTOM_FONTS_ADDING_FONT_MSG', "Consummatio font ...");
define('MANAGE_CUSTOM_FONTS_ADDING_FONT_COMPLETE_MSG', "Consummatio plenaria font.");
define('MANAGE_CUSTOM_FONTS_ADDING_FONT_1_ERR', "font est fons");
define('MANAGE_CUSTOM_FONTS_ADDING_FONT_2_ERR', "iam est.");
define('MANAGE_CUSTOM_FONTS_ADDING_FONT_UPLOAD_ERR', "Paenitet, vestrum est error discas font.");
define('MANAGE_CUSTOM_FONTS_ADDING_FONT_FILE_TYPE_ERR', "Paenitet, tantum III, OTF, WOFF, WOFF2, SVG &amp; EOT imagini non licet.");
define('MANAGE_CUSTOM_FONTS_DELETE_FONT_CONFIRM_1_MSG', "Es vos certus vos volo ut delete");
define('MANAGE_CUSTOM_FONTS_DELETE_FONT_CONFIRM_2_MSG', "font est fons");
define('MANAGE_CUSTOM_FONTS_DELETE_FONT_CONFIRM_3_MSG', "?");
define('MANAGE_CUSTOM_FONTS_DELETE_FONT_COMPLETE_MSG', "Font delevit.");

////////////////////// Clear All Custom CSS Classes /////////////////////////////////////
// Buttons:
define('CLEAR_CUSTOM_CSS_CLASSES_HEADING', "Aequaliter Nubila Custom CSS classes");
// Console Text:
define('CLEAR_CUSTOM_CSS_CLASSES_ALL_STYLE_SHEETS', "Omnis Style rudentis");
// Popup Messages:
define('CLEAR_CUSTOM_CSS_CLASSES_WARNING_MSG', "CAVE: Haec operatio procedens apud intime afficiunt vestri website. Id fieri infectum non potest. Visne tu permanere?");
define('CLEAR_CUSTOM_CSS_CLASSES_WARNING_2_MSG', "CAVE: Haec reseting operationem ordinatur ad auxilium in vestri website, vel a particulari, vel plugin menu ad officinas defaltis. <br /> Id fieri infectum non potest. Haec est ultima admonitio. Vis permanere?");
define('CLEAR_CUSTOM_CSS_CLASSES_START_MSG', "More ... About MULTATIO classes");
define('CLEAR_CUSTOM_CSS_CLASSES_COMPLETE_MSG', "About MULTATIO consuetudine classes plena.");
define('CLEAR_CUSTOM_CSS_CLASSES_COMPLETE_ERR', "Purgandi ordines CSS mos fuit error.");

////////////////////// Backup/Restore /////////////////////////////////////
// Buttons:
define('BACKUP_RESTORE_HEADING', "Tergum quod Restituo Site");
// Console Text:
define('BACKUP_RESTORE_SELECT_BACKUP', "Tergum Lego to Redde");
define('BACKUP_RESTORE_SELECT_BACKUP_TO_UPLOAD', "Tergum tuo te potissimum reficiendum General");
define('BACKUP_RESTORE_DELETE_BACKUP', "delete tergum");
define('BACKUP_RESTORE_RETAIN_MEDIA', "Disputatio imagines reddet, et current media");
define('BACKUP_RESTORE_UPLOAD_LARGE_BKUPS_MSG', "Uploading tergum lima ut non magis quam CCC Megabytes. Si hoc fit, FTP vestri tergum lima ut in &#39;tergum, et curam public_html folder sub hoc consolatorium.");
// Popup Messages:
define('BACKUP_RESTORE_CREATING_BACKUP_PLEASE_WAIT_MSG', "Tergum sursum site Sede ...");
define('BACKUP_RESTORE_UPLOADING_BACKUP_PLEASE_WAIT_MSG', "Uploading tergum, please wait ...");
define('BACKUP_RESTORE_RESTORING_WEBSITE', "Scroll to website .... fundum restitueret, cum completum.");
define('BACKUP_RESTORE_RESTORE_CONFIRM_1_MSG', "Visne tu restitui ex");
define('BACKUP_RESTORE_RESTORE_CONFIRM_2_MSG', "Tergum file?");
define('BACKUP_RESTORE_DELETE_BACKUP_CONFIRM_MSG', "Es vos certus vos volo ut delete");
define('BACKUP_RESTORE_DELETE_BACKUP_SUCCESS_MSG', "Tergum file deleta est.");
define('BACKUP_RESTORE_DELETE_BACKUP_ERROR_ERR', "Deletis error fuit tergum lima.");
define('BACKUP_RESTORE_ERROR_CREATING_FOLDER_ERR', "Non est creans");
define('BACKUP_RESTORE_ERROR_ERROR_WRITING_FILE_ERR', "Potest non scribere ad file");
define('BACKUP_RESTORE_BACKUP_COMPLETE_MSG', "Tergum est plena!");
define('BACKUP_RESTORE_BACKUP_READY_FOR_DOWNLOAD_1_MSG', "Parata download tergum tuum.");
define('BACKUP_RESTORE_BACKUP_READY_FOR_DOWNLOAD_2_MSG', "download ad vestri tergum.");
define('BACKUP_RESTORE_RETURN_TO_MSG', "redire ad Tergum / Redde Console");
define('BACKUP_RESTORE_WRONG_FILE_TYPE_1_MSG', "Sed zipped files aut bitumen gzipped file uploaded liceat, id est, backup_54121247.zip &#39;vel&#39; backup_54121247.tgz &#39;vel&#39; backup_54121247.tar.gz. Please click");
define('BACKUP_RESTORE_RESTORE_COMPLETE', "Site restitutio sit omnino.");
define('BACKUP_RESTORE_DUMPING_DATABASE', "... Dumping Database");
define('BACKUP_RESTORE_ZIPPING_FILES', "Archiving files ...");



///////////////// Standard words and phrases ///////////////////////
define('WELCOME_WORD', "About");
define('ACCESS_LEVEL_WORD', "obvius Level");
define('YES_WORD', "Etiam");
define('NO_WORD', "No");
define('SUBMIT_WORD', "submit");
define('OK_WORD', "consentio");
define('CANCEL_WORD', "Cancel");
define('VERSION_WORD', "Version");
define('USERID_WORD', "Id Disputatio");
define('USERNAME_WORD', "User Name");
define('PASSWORD_WORD', "Password");
define('EMAIL_WORD', "Email");
define('NAME_WORD', "User Name");
define('DASHBOARD_WORD', "Dashboard");
define('SAVE_AS_WORD', "Save as");
define('CREATE_WORD', "Create");
define('UPDATE_WORD', "Update");
define('REQUIRED_WORD', "requiritur,");
define('OPTIONAL_WORD', "ad libitum");
define('PLUGINS_WORD', "Plugins");
define('RIGHT_WORD', "rectus");
define('LEFT_WORD', "reliquit");
define('TOP_WORD', "Top");
define('BOTTOM_WORD', "imo");
define('HEADER_WORD', "caput mortuum");
define('FOOTER_WORD', "footer");
define('HEAD_WORD', "caput");
define('ERROR_WORD', "Error");
define('ERROR_CAPS_WORD', "VITIUM");
define('HERE_WORD', "hic");
define('NEW_WORD', "novus");
define('DESCRIPTION_WORD', "Description");
define('DATE_WORD', "Update");
define('LINK_WORD', "Link");
define('TARGET_WORD', "Target");
define('ACTIVE_WORD', "Active");
define('USER_TABLE_WORD', "User Table");
define('HEADER_1ST_CAP_WORD', "Header");
define('TOP_1ST_CAP_WORD', "Top");
define('LEFT_1ST_CAP_WORD', "Left");
define('RIGHT_1ST_CAP_WORD', "ius");
define('BOTTOM_1ST_CAP_WORD', "solum");
define('FOOTER_1ST_CAP_WORD', "footer");
define('HEAD_1ST_CAP_WORD', "caput");
define('VERTICAL_WORD', "vertical");
define('HORIZONTAL_WORD', "vestibulum");
define('OFFSET_WORD', "cinguli");
define('POSITION_WORD', "positio");
define('POSITIONING_WORD', "positioning");
define('ABSOLUTE_WORD', "Absolutus");
define('RELATIVE_WORD', "Relative");
define('WIDTH_WORD', "latitudo");
define('HEIGHT_WORD', "Height");
define('PROPORTIONAL_WORD', "proportionalis");
define('PADDING_WORD', "Nam libero tempore,");
define('ORIENTATION_WORD', "propensionis");
define('CENTER_WORD', "Center");
define('JUSTIFY_WORD', "iustifica");
define('FONT_WORD', "Font");
define('SIZE_WORD', "Size");
define('WEIGHT_WORD', "Weight");
define('ITALIC_WORD', "Medium");
define('UNDERLINE_WORD', "underline");
define('OVERLINE_WORD', "overline");
define('LINETHROUGH_WORD', "Linethrough");
define('BLINK_WORD', "Blink");
define('OBLIQUE_WORD', "Oblique");
define('SHADOW_WORD', "Umbra");
define('COLOR_WORD', "Color");
define('X_OFFSET_WORD', "X-offset");
define('Y_OFFSET_WORD', "Y-offset");
define('BLUR_WORD', "LABES");
define('OPACITY_WORD', "opacity");
define('WEBSAFE_WORD', "Websafe");
define('NA_WORD', "na");
define('NORMAL_WORD', "Normal");
define('BOLD_WORD', "Medium");
define('BOLDER_WORD', "boldur");
define('LIGHTER_WORD', "levioribus");
define('INITIAL_WORD', "Initial");
define('INHERIT_WORD', "possidete");
define('INITIAL_LC_WORD', "Initial");
define('INHERIT_LC_WORD', "possidebit");
define('RGB_WORD', "#RRGGBB");
define('TEXT_WORD', "Text");
define('ALIGN_WORD', "align");
define('BACKGROUND_WORD', "Background");
define('BORDER_WORD', "terminus");
define('SPREAD_WORD', "Expande,");
define('INSET_WORD', "inset");
define('BASELINE_WORD', "baseline");
define('SUB_WORD', "Sub");
define('SUPER_WORD', "Super");
define('MIDDLE_WORD', "medium");
define('NONE_WORD', "Omnia");
define('RADIUS_WORD', "radium");
define('MARGIN_WORD', "margin");
define('AUTO_WORD', "Auto");
define('DISPLAY_WORD', "Display");
define('VISIBILITY_WORD', "Visibilitas");
define('OVERFLOW_WORD', "redundabunt");
define('FLOAT_WORD', "supernatet");
define('CLIPPING_WORD', "Clipping");
define('IMAGE_WORD', "Image");
define('ATTACHMENT_WORD', "attachment");
define('REPEAT_WORD', "repeat");
define('LIST_WORD', "album");
define('TYPE_WORD', "Type");
define('FIXED_WORD', "Fixarum");
define('SCROLL_WORD', "Scroll");
define('SCROLLING_WORD', "scrolling");
define('INLINE_WORD', "inline");
define('BLOCK_WORD', "Block");
define('COMPACT_WORD', "foedus");
define('MARKER_WORD', "Venalicium");
define('TABLE_WORD', "User Table");
define('XX_SMALL_WORD', "parva-XX");
define('X_SMALL_WORD', "parva-XX");
define('SMALL_WORD', "parva-XX");
define('MEDIUM_WORD', "medium");
define('LARGE_WORD', "magna");
define('X_LARGE_WORD', "X-Large");
define('XX_LARGE_WORD', "XX-Large");
define('SMALLER_WORD', "minus");
define('LARGER_WORD', "maior");
define('NO_WRAP_WORD', "non AMICTORIUM");
define('PRE_WORD', "Pre");
define('PRE_LINE_WORD', "Pre-Versus");
define('PRE_WRAP_WORD', "Pre-AMICTORIUM");
define('POINTER_WORD', "Indicium");
define('CROSSHAIR_WORD', "Maximus");
define('DEFAULT_WORD', "Default");
define('WAIT_WORD', "Manere");
define('HELP_WORD', "auxilium");
define('ALIAS_WORD', "alias");
define('CELL_WORD', "Cell");
define('COPY_WORD', "Copy");
define('RENAME_WORD', "Rename");
define('MOVE_WORD', "Move");
define('ASSIGN_WORD', "assignare");
define('PROGRESS_WORD', "Progress");
define('HIDDEN_WORD', "occultus");
define('DOTTED_WORD', "dotted");
define('DASHED_WORD', "elisi");
define('SOLID_WORD', "Solidum");
define('DOUBLE_WORD', "geminus");
define('GROOVE_WORD', "sulcus");
define('RIDGE_WORD', "Ridge");
define('OUTSET_WORD', "ab initio");
define('COLLAPSE_WORD', "collapse");
define('SEPARATE_WORD', "Separate");
define('MIN_WORD', "Min");
define('MAX_WORD', "Max");
define('VISIBLE_WORD', "visibilis");
define('BOTH_WORD', "tum");
define('STATIC_WORD', "static");
define('SCALE_WORD', "scale");
define('COVER_WORD', "Cover");
define('CONTAIN_WORD', "continent");
define('DISC_WORD', "Disc");
define('CIRCLE_WORD', "orbis");
define('SQUARE_WORD', "Square");
define('DECIMAL_WORD', "Decimal");
define('HEBREW_WORD', "Hebrew");
define('ARMENIAN_WORD', "Armenia");
define('GORGIAN_WORD', "Georgian");
define('INSIDE_WORD', "Inside");
define('OUTSIDE_WORD', "extra");
define('CLASS_WORD', "Class");
define('SUBCLASS_WORD', "genus");
define('ID_WORD', "Id Disputatio");
define('CUSTOM_WORD', "Custom");
define('_NONE_WORD', "-None-");
define('ADD_WORD', "Add");
define('OWNER_WORD', "dominus");
define('AUTHOR_WORD', "Author:");
define('COPYRIGHT_WORD', "Copyright");
define('LANGUAGE_WORD', "Language");
define('ABSTRACT_WORD', "Abstract");
define('KEYWORDS_WORD', "Keywords");
define('SUBJECT_WORD', "Subject");
define('ROBOTS_WORD', "robots");
define('INDEX_WORD', "Index");
define('FOLLOW_WORD', "Follow");
define('REVISIT_WORD', "Repete");
define('DAYS_WORD', "diebus");
define('OR_WORD', "Error");
define('OR_CAP_WORD', "VEL");
define('TO_WORD', "Auto");
define('CLICK_WORD', "Click");
define('PAGE_WORD', "page");
define('PAGE_1ST_CAP_WORD', "Page");
define('CONTENT_WORD', "Content");
define('DELETED_WORD', "delevit");
define('BACKUP_WORD', "Tergum");
define('RESTORE_WORD', "redde");
define('REMOVE_WORD', "Remove");
define('CLOSE_WORD', "Close");
define('INSTALL_WORD', "Install");
define('ADMIN_WORD', "Maecenas et ipsum");
define('POWER_USER_WORD', "User potentia");
define('USER_WORD', "User potentia");
define('RESTRICTED_WORD', "restricted");
define('BLOGGER_WORD', "Blogger");
define('RECIPIENT_WORD', "recipient");
define('READING_WORD', "Reading");
define('PARSING_WORD', "parsing");
define('RECALL_WORD', "Recordare");
define('OPTION_WORD', "option");
define('VALUE_WORD', "Value");
define('MOBILE_WORD', "Mobile");
define('TRANSPARENT_WORD', "perspicuus");
define('SOURCE_WORD', "Source");
define('CONDENSED_WORD', "Medium");
define('ULTRA_CONDENSED_WORD', "Condensed Ultra-");
define('EXTRA_CONDENSED_WORD', "-Bold Italic");
define('SEMI_WORD', "Semi Condensed");
define('EXPANDED_WORD', "expanded");
define('SEMI_EXPANDED_WORD', "Quid Expanded");
define('EXTRA_EXPANDED_WORD', "Extra-Expanded");
define('ULTRA_EXPANDED_WORD', "Ultra-Expanded");
define('INDENT_WORD', "Maius");
define('BUILDING_WORD', "Building");
define('STYLE_SHEET_WORD', "style");
define('TITLE_WORD', "Title:");
define('REFRESH_WORD', "Refresh");
define('FOLDER_WORD', "folder");
define('DOWNLOAD_WORD', "Download");

define('QUERY_READY_TO_SEND', "Mitte ad query ...");
define('QUERY_SENT', "misit query");
define('QUERY_COMPLETE', "The query");
define('QUERY_COMPLETE_NO_RECORD_FOUND', "Query perfecta. No records.");
define('SELF_NORMAL', "Ipsum (normalis)");
define('NEW_WINDOW', "New Window");
define('NAMED_FRAME', "Frame nomine");
define('ENTER_FRAME_NAME', "intrat frame nomine");
define('TEXT_ALIGNMENT', "noctis Text");
define('_NOT_SELECTED_', "X! Et oblitus es eligere page / aut plugin.");
define('_NOT_SET_', "Set- iactatis");
define('_NOT_ASSIGNED_', "assigned- iactatis");
define('LETTER_SPACING', "Epistula Spacing");
define('SMALL_CAPS', "Small Caps");
define('MOUSE_OUT', "Normal (de mus)");
define('MOUSE_OVER', "Hover (in Mus)");
define('FONT_SIZE', "Font Size");
define('BOX_SHADOW', "Box Umbra");
define('BACKGROUND_COLOR', "Top Level Background Colo");
define('BORDER_COLOR', "Top Level Block Border Color");
define('BORDER_STYLE', "terminus Style");
define('HORIZONTAL_OFFSET', "horizontal offset");
define('VERTICAL_OFFSET', "vertical cinguli");
define('TEXT_TOP', "Top Text");
define('TEXT_BOTTOM', "Solum Text");
define('VERTICAL_ALIGN', "vertical Align");
define('LINE_HEIGHT', "Line Height");
define('SORT_ORDER', "Set Class Genus Ordo");
define('LAST_REVISED', "Last Latin");
define('GENERATE_PASSWORD', "Password ingenero");
define('CHANGE_PASSWORD', "Change Password");
define('ACCESS_LEVELS', "Transfiguratus accessum gradus ...");
define('ADD_USER', "Eligere oportet primum mensam apponere user.");
define('MODIFY_USER', "User modify");
define('DELETE_USER', "Visne tu delere usoris");
define('NEW_PASSWORD', "New Password");
define('SELECT_ALL', "lego All");
define('CLEAR_ALL', "About Omnia Custom Classes Lockout Nubila");
define('TO_TRY_AGAIN', "ut iterum experiri.");
define('AND_TRY_AGAIN', "et rursum.");
define('NEW_FILE', "File New");
define('NEW_FOLDER', "New Folder");
define('FOLDER_NAME', "folder nomen");
define('SHOW_BACKUP_FILES', "Show Tergum Files");
define('EDIT_MENU_ITEMS_MEGA_MENU', "Mega");
define('MEGA_MENU_MANAGE_BTN', "Mega Manage Menus");
define('MEGA_MENU_EDIT_SELECT_HEADING', "Mega Emendo Menus");
define('MEGA_MENU_CREATE_HEADING', "Create Mega Menu");
define('MEGA_MENU_BACK_BTN', "Back to Menu Item Edit");
define('MEGA_MENU_PAGE_ALREADY_EXISTS_1_ERR', "Mega");
define('MEGA_MENU_PAGE_ALREADY_EXISTS_2_ERR', "iam est. Nomen edit inter alia Please enter existens.");
define('MENU_WORD', "Menu");
define('MENU_ITEM', "Menu");
define('MANAGE_CUSTOM_BORDER_AREA_ADD_AREA_BTN', "Add another terminus area");
define('MANAGE_CUSTOM_BORDER_AREA_BACK_BTN', "Back to Manage terminus areas");
define('MANAGE_HEAD_BACK_BTN', "Back to Edit caput Code");
define('MANAGE_HEAD_MANAGE_BTN', "Curo Code caput Custom");
define('OPTIONS_ENABLE_CSS_MENUS', "Enable CSS Menus");
define('OPTIONS_ENABLE_JS_MENUS', "JavaScript Menus");
define('EDITOR_BACK_TO_SELECT', "Back to Select");
define('COPY_STYLE_TO_MOBILE_BACK_TO_EDIT_CSS_SELECT_BTN', "Back to Select Edit Styles");
define('EDIT_STYLE_SHEET_ATT_BTN', "Sheet attributa Manage Style");
define('MANAGE_STYLE_SHEET_ATT_HEADING', "Sheet attributa Manage Style");
define('MANAGE_STYLE_SHEET_ATT_BACK_TO_EDIT_CSS_SELECT', "Back to Select Edit CSS");
define('MANAGE_STYLE_SHEET_ATT_CHARSET', "charset");
define('MANAGE_STYLE_SHEET_ATT_IMPORT', "Import");
define('MANAGE_STYLE_SHEET_ATT_MEDIA', "Media");
define('MANAGE_STYLE_SHEET_ATT_MEDIA_TYPE', "Media Type");
define('MANAGE_STYLE_SHEET_ATT_MEDIA_FEATURE', "Media Feature");
define('MANAGE_STYLE_SHEET_ATT_MEDIA_FEATURE_VALUE', "Media Feature Value");
define('MANAGE_STYLE_SHEET_ATT_ADD_STYLE_SHEET', "Add Style Sheet");
define('MANAGE_STYLE_SHEET_ATT_DELETE_STYLE_SHEET', "Delete Style Sheet");
define('MANAGE_STYLE_SHEET_ATT_RENAME_STYLE_SHEET', "Rename Style Sheet");
define('MANAGE_STYLE_SHEET_ATT_NEW_NAME', "nomine");
define('MANAGE_STYLE_SHEET_ATT_NEW_DESC', "Description New");
define('MANAGE_STYLE_SHEET_ATT_SAVE_SUCCESS_MSG', "Style rudentis vestra attributa fuisse salvandi.");
define('MANAGE_STYLE_SHEET_ATT_SAVE_ERROR_ERR', "Style rudentis salva attributa fuit error.");
define('MANAGE_STYLE_SHEET_ATT_ADD_SUCCESS_MSG', "Style salva facta tui.");
define('MANAGE_STYLE_SHEET_ATT_ADD_SHEET_ALREADY_EXISTS_ERR', "Ut dictum est, style. Elige rursum alio nomine");
define('MANAGE_STYLE_SHEET_ATT_ADD_ERROR_ERR', "Erat styli errorem addit p.");
define('MANAGE_STYLE_SHEET_ATT_DELETE_CONFIRM_MSG', "Es vos certus vos volo ut delete");
define('MANAGE_STYLE_SHEET_ATT_DELETE_SUCCESS_MSG', "Style tua deleta.");
define('MANAGE_STYLE_SHEET_ATT_DELETE_ERROR_ERR', "Deletis errorem tuum style erat.");
define('MANAGE_STYLE_SHEET_ATT_RENAME_SUCCESS_MSG', "Tuus fuerit style appellati.");
define('MANAGE_STYLE_SHEET_ATT_RENAME_ERROR_ERR', "Fuit erroris vestri penicullus renaming p.");
define('NOT_WORD', "non");
define('ONLY_WORD', "tantum");
define('ALL_WORD', "Omnia");
define('PRINT_WORD', "Print");
define('SCREEN_WORD', "Screen");
define('SPEECH_WORD', "oratio");
define('AND_WORD', "et");
define('DESKTOP_WORD', "Desktop");
define('MIN_WIDTH', "Min Width");
define('MAX_WIDTH', "Max Width");
define('MIN_HEIGHT', "Min Height");
define('MAX_HEIGHT', "Max Height");
define('GET_MORE_PLUGINS_BTN', "Get More Plugins");
define('GET_MORE_TEMPLATES_BTN', "Get More Templates");
define('MANAGE_STYLE_SHEET_ATT_EXCLUDE_FROM_LIST', "Excludere a default album");
define('MANAGE_STYLE_SHEET_ATT_SHOW_CUSTOM_STYLES', "Show more Styles");
define('MANAGE_STYLE_SHEET_ATT_SHOW_ALL', "Show Style rudentis");
define('UPLOAD_TEMPLATE_UPLOAD_TEMPLATE_COMPLETE', "Template installation est universa.");
define('CREATE_PAGE_SELECT_CREATE_PLUGIN_GROUP', "Creare plugin pages ad haec coetus plugin");
define('CREATE_PAGE_SELECT_ALREADY_EXISTS_ERR', "Undefined");
define('MANAGE_STYLE_SHEET_SET_SORT_ORDER', "Set Style Sheet Genus Ordo");
define('MANAGE_STYLE_SHEET_NAME_DESCRIPTION', "Sheet Style / Description");
define('EDIT_CSS_SHOW_ALL_CLASSES', "Show omnes classes");
define('EDIT_CSS_MENU_STYLES_OMIT_ADJACENT_BORDERS', "O&lt;br&gt;m&lt;br&gt;i&lt;br&gt;t&lt;br&gt;&lt;br&gt;A&lt;br&gt;d&lt;br&gt;j&lt;br&gt;a&lt;br&gt;c&lt;br&gt;e&lt;br&gt;n&lt;br&gt;t&lt;br&gt;&lt;br&gt;B&lt;br&gt;o&lt;br&gt;r&lt;br&gt;d&lt;br&gt;e&lt;br&gt;r&lt;br&gt;s");
define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_1_SIZE_PADDING', "Nam libero tempore Size et sub Menu Item I");
define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_2_SIZE_PADDING', "II Item Nam libero tempore Size et sub Menu");
define('EDIT_CSS_MENU_PARAMETERS_ITEM_SPACING', "item Spacing");
define('EDIT_CSS_MENU_STYLES_DOWN', "Et (button descendit)");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_BACKGROUND_COLOR', "Background Colo colui cultum sub Level I");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_BACKGROUND_COLOR', "Finis");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_ITEM_BORDER_COLOR', "Item Border Color sub Level I");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_ITEM_BORDER_COLOR', "Level II Item sub Border Color");
define('EDIT_CSS_MENU_STYLES_PARAMS_NOT_SET_ERR_1', "Quoniam non posuit parametri Explore. Please click");
define('EDIT_CSS_MENU_STYLES_PARAMS_NOT_SET_ERR_2', "menu setup ut CSS parametri");
define('BORDER_RADIUS', "terminus ipsius Radium");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1', "Sub Level I");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2', "Sub Level II");
define('EDIT_MENU_ITEMS_ADD_BEFORE_SAVE_NEW_MSG', "Item tibi novam, quae non servatae sunt. Item ut libera ante addita fuit.");
define('EDIT_CSS_MENU_STYLES_SHADOW_COLOR', "Colo colui cultum umbra");
define('EDIT_CSS_MENU_STYLES_HOVER_ON_DOWN', "Est in tabernus");
define('EDIT_CSS_FOREGROUND_OPAQUE_1', "corporis fabrica");
define('EDIT_CSS_FOREGROUND_OPAQUE_2', "opacum");
define('ADMIN_FUNCTION_SELECT_RESTRICT_BLOG_PAGE_EDITING_ACCESS_BTN', "Page restringere Blog Access PL |");
define('RESTRICT_BLOG_EDITING_HEADING', "Aenean eget ante enim Termino Obvius ut Bloggers");
define('USERS_WORD', "users");
define('PUBLISHED_WORD', "published");
define('DRAFT_WORD', "capturam");
define('ADD_ALL', "addere omnes");
define('BLOG_PAGE', "Page Blog");
define('EDIT_CSS_FLEX', "LENTO");
define('EDIT_CSS_INLINE_FLEX', "Inline-LENTO");
define('EDIT_CSS_CONTENT_TEXT', "content Text");
define('EDIT_CSS_JUSTIFY_CONTENT', "Content justify");
define('EDIT_CSS_SET_CONTENT_BLANK', "Set Page Content");
define('EDIT_CSS_FLEX_START', "Satus LENTO");
define('EDIT_CSS_FLEX_END', "LENTO finis");
define('EDIT_CSS_SPACE_BETWEEN', "iNTERVALLUM");
define('EDIT_CSS_SPACE_AROUND', "eius per gyrum");
define('EDIT_CSS_SET_DISPLAY_FLEX', "Constitue View LENTO");
define('EDIT_CSS_WRAP_REVERSE', "wrap inversa");
define('EDIT_CSS_ROW_REVERSE', "row inversa");
define('EDIT_CSS_COLUMN_REVERSE', "Finis");
define('EDIT_CSS_DISPLAY_SET_TO_FLEX', "Et profectus est ad ostentationem proprium est &#39;flex.");
define('EDIT_CSS_CONTENT_SET_TO_BLANK', "Est filum, -blank- &#39;narrat compliler ut CSS filum de content est&#39;.");
define('WRAP_WORD', "wrap");
define('CAPITALIZE_WORD', "capitalize");
define('UPPERCASE_WORD', "uppercase");
define('LOWERCASE_WORD', "lowercase");
define('STRING_WORD', "filum");
define('ATTRIBUTE_WORD', "attributum,");
define('COUNTER_WORD', "counter");
define('TRANSITION_WORD', "Selenium");
define('PROPERTY_WORD', "possessionem");
define('DURATION_WORD', "Finis");
define('DELAY_WORD', "mora");
define('EASE_WORD', "otium");
define('LINEAR_WORD', "linearibus");
define('BASIS_WORD', "ex");
define('GROW_WORD', "crescere");
define('SHRINK_WORD', "shrink");
define('LENGTH_WORD', "longitudo");
define('DIRECTION_WORD', "partem");
define('ROW_WORD', "row");
define('COLUMN_WORD', "columnae");
define('TEXT_TRANSFORM', "Transform text");
define('OPEN_QUOTE', "aperta Quotes");
define('CLOSE_QUOTE', "prope Quotes");
define('NO_OPEN_QUOTE', "Nihil palam Quotes");
define('NO_CLOSE_QUOTE', "Nec finem ullum Quotes");
define('TIMING_FUNCTION', "leo Function");
define('EASE_IN', "Et relevabor");
define('EASE_OUT', "Ex relevabor");
define('EASE_IN_OUT', "Et quod de facile amittitur");
define('WIDTH_AND_HEIGHT', "Vivamus ipsum");
define('EDIT_CSS_ENTER_STR_MSG', "Intra textus contentus ut ad ad agro Content Text initus, aut relinqueret blank ut in textu blank.");
define('EDIT_CSS_ENTER_URL_MSG', "Intra agrum initus Text Content in domicilio.");
define('EDIT_CSS_ENTER_ATTR_MSG', "Attribite HTML ingressum secundum, scilicet href vel nomen Contentus text input in agro.");
define('IMPORTANT_HEADING', "Curo Important CSS haec attributa?");
define('MANAGE_PAGE_ACCESS_NO_LOGIN_FIELDS_IN_TABLE_ERR', "Mensa enim defuit user-login agris. Si vis user accessum ad hanc mensam, primus addere oportet ad hanc mensam per agros user-login per &#39;Agri addere Login autem Iob dixit&#39; deprimendo.");
define('THRU_WORD', "thru");
define('OF_WORD', "autem");
define('SHOWING_RECORDS', "showing records");
define('FIRST_NAME', "Praenomen");
define('LAST_NAME', "Cognomen");
define('EDIT_CSS_MENU_PARAMETERS_LATCH_EXPANDED_ON_DOWN', "In pessulus Item Est Chinese subs");
define('RADIAL_WORD', "aculeis");
define('ANGLE_WORD', "Angulus");
define('DEGREES_WORD', "gradus");
define('BACKGROUND_GRADIENT', "background Gradiente");
define('TOP_TO_BOTTOM', "Supremas, quam infimas");
define('BOTTOM_LEFT_TO_TOP_RIGHT', "Bottom left right to Top");
define('LEFT_TO_RIGHT', "Finis");
define('TOP_LEFT_TO_BOTTOM_RIGHT', "Top left to bottom right");
define('BOTTOM_TO_TOP', "Imo ad summum");
define('TOP_RIGHT_TO_BOTTOM_LEFT', "Summo iure imo Umbra");
define('RIGHT_TO_LEFT', "Dextrorsum et sinistrorsum");
define('BOTTOM_RIGHT_TO_TOP_LEFT', "Top fundo ius Umbra");
define('EDIT_CSS_MENU_PARAMETERS_SUB_1_MENU_POSITIONING', "I layout fecit et sub Menu");
define('EDIT_CSS_MENU_PARAMETERS_SUB_2_MENU_POSITIONING', "II layout fecit et sub Menu");
define('HOVER_WORD', "Suum cuique pulchrum est");
define('DOWN_WORD', "descendit");
define('EDIT_CSS_MENU_PARAMETERS_BASE_Z_INDEX', "Basis margin-right");
define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_1', "Illic es plugins nullum genus sub");
define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_2', "Click");
define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_3', "locate, quod est genus a plugin in.");
define('MAIN_MENU_MANAGE_MY_ACCOUNT_BTN', "Curo My Account");
define('MAIN_MENU_SHOW_PASSWORD_RESET_MSG', "Vestri password in tempus est updated cum password. Suadetur ut mutare vestri password ut somethitng est facillimus ut typus et recordabor contrahas et quasi reponas in vestri password tutum locum novam. Tu autem vis ad mutare vestri password?");
define('MANAGE_USERS_CHANGE_MY_PASSWORD', "Mutata meum Password");
define('MANAGE_USERS_MODIFY_MY_ACCOUNT', "Mutari My Account");
define('STICKY_WORD', "Pellentesque");
define('EDIT_CSS_SETUP_STICKY_HEADER_BTN', "Pellentesque setup nam Header");
define('EDIT_CSS_LOAD_STICKY_HEADERS_ALERT_MSG', "Nos mos iam load de causa dicendi generibus et occasus erit super caput tuum paginas telae, quae est &#39;lignum&#39; in vestri pasco fenestra est summitatem.");
define('EDIT_CSS_LOAD_STICKY_HEADERS_COMPLETE_MSG', "Et nunc inhaero vestri caput capitis in vertice ad pasco fenestra.");
define('UPLOAD_TEMPLATE_COPYING_FONTS_MSG', "Effingo ... fonts");
define('MANAGE_MENUS_COPY_MENU_BTN', "exemplum Menu");
define('MANAGE_MENUS_COPY_MENU_ITEMS_TO_MOBILE_BTN', "Item exemplum Menu");
define('MANAGE_MENUS_CREATE_NEW', "novum Menu");
define('MANAGE_MENUS_COPY_MENU_CONFIRM_1_MSG', "Esne certus vos volo ut effingo quod");
define('MANAGE_MENUS_COPY_MENU_CONFIRM_2_MSG', "in menu");
define('MANAGE_MENUS_COPY_MENU_CONFIRM_3_MSG', "menu?");
define('MANAGE_MENUS_COPY_MENU_ITEMS_CONFIRM_2_MSG', "in menu items");
define('TO_1ST_CAP_WORD', "Ad");
define('FROM_WORD', "Ex");
define('MANAGE_MENUS_COPY_MENU_ITEMS_TO_MOBILE_HEADING', "Menu Item exemplum ut Desktop, mobile sive Touchscreen Menu");
define('MANAGE_MENUS_DESTINATION_TYPE', "Destination Type");
define('TOUCHSCREEN_WORD', "touchscreen");
define('MANAGE_STYLE_SHEET_ATT_COPY_SUCCESS_MSG', "Tuum style sheet est prima ad naturalia.");
define('MANAGE_STYLE_SHEET_ATT_COPY_ERROR_ERR', "Sed error fuit exscribend testatem tuum style sheet.");
define('COPY_STYLE_TO_MOBILE_SOURCE_TYPE', "fons Type");
define('EDIT_CSS_SELECT_DESTINATION_TYPE_NOT_SELECTED', "Destination genus non lectus. Select a forum quod genus iterum conare.");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_BLOCK_BORDER_COLOR', "Level II Acta sub Border Color");
?>